/*!
 *  Font Awesome 4.7.0 by @davegandy - http://fontawesome.io - @fontawesome
 *  License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
/* FONT PATH
 * -------------------------- */
@font-face {
  font-family: 'FontAwesome';
  src: url(674f50d287a8c48dc19ba404d20fe713.eot);
  src: url(674f50d287a8c48dc19ba404d20fe713.eot?#iefix&v=4.7.0) format("embedded-opentype"), url(af7ae505a9eed503f8b8e6982036873e.woff2) format("woff2"), url(fee66e712a8a08eef5805a46892932ad.woff) format("woff"), url(b06871f281fee6b241d60582ae9369b9.ttf) format("truetype"), url(912ec66d7572ff821749319396470bde.svg#fontawesomeregular) format("svg");
  font-weight: normal;
  font-style: normal; }

.fa {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale; }

/* makes the font 33% larger relative to the icon container */
.fa-lg {
  font-size: 1.33333333em;
  line-height: 0.75em;
  vertical-align: -15%; }

.fa-2x {
  font-size: 2em; }

.fa-3x {
  font-size: 3em; }

.fa-4x {
  font-size: 4em; }

.fa-5x {
  font-size: 5em; }

.fa-fw {
  width: 1.28571429em;
  text-align: center; }

.fa-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none; }

.fa-ul > li {
  position: relative; }

.fa-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center; }

.fa-li.fa-lg {
  left: -1.85714286em; }

.fa-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eeeeee;
  border-radius: .1em; }

.fa-pull-left {
  float: left; }

.fa-pull-right {
  float: right; }

.fa.fa-pull-left {
  margin-right: .3em; }

.fa.fa-pull-right {
  margin-left: .3em; }

/* Deprecated as of 4.4.0 */
.pull-right {
  float: right; }

.pull-left {
  float: left; }

.fa.pull-left {
  margin-right: .3em; }

.fa.pull-right {
  margin-left: .3em; }

.fa-spin {
  -webkit-animation: fa-spin 2s infinite linear;
  animation: fa-spin 2s infinite linear; }

.fa-pulse {
  -webkit-animation: fa-spin 1s infinite steps(8);
  animation: fa-spin 1s infinite steps(8); }

@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg); } }

@keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg); } }

.fa-rotate-90 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg); }

.fa-rotate-180 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg); }

.fa-rotate-270 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
  -webkit-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg); }

.fa-flip-horizontal {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
  -webkit-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  transform: scale(-1, 1); }

.fa-flip-vertical {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
  -webkit-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  transform: scale(1, -1); }

:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical {
  filter: none; }

.fa-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle; }

.fa-stack-1x,
.fa-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center; }

.fa-stack-1x {
  line-height: inherit; }

.fa-stack-2x {
  font-size: 2em; }

.fa-inverse {
  color: #ffffff; }

/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.fa-glass:before {
  content: "\F000"; }

.fa-music:before {
  content: "\F001"; }

.fa-search:before {
  content: "\F002"; }

.fa-envelope-o:before {
  content: "\F003"; }

.fa-heart:before {
  content: "\F004"; }

.fa-star:before {
  content: "\F005"; }

.fa-star-o:before {
  content: "\F006"; }

.fa-user:before {
  content: "\F007"; }

.fa-film:before {
  content: "\F008"; }

.fa-th-large:before {
  content: "\F009"; }

.fa-th:before {
  content: "\F00A"; }

.fa-th-list:before {
  content: "\F00B"; }

.fa-check:before {
  content: "\F00C"; }

.fa-remove:before,
.fa-close:before,
.fa-times:before {
  content: "\F00D"; }

.fa-search-plus:before {
  content: "\F00E"; }

.fa-search-minus:before {
  content: "\F010"; }

.fa-power-off:before {
  content: "\F011"; }

.fa-signal:before {
  content: "\F012"; }

.fa-gear:before,
.fa-cog:before {
  content: "\F013"; }

.fa-trash-o:before {
  content: "\F014"; }

.fa-home:before {
  content: "\F015"; }

.fa-file-o:before {
  content: "\F016"; }

.fa-clock-o:before {
  content: "\F017"; }

.fa-road:before {
  content: "\F018"; }

.fa-download:before {
  content: "\F019"; }

.fa-arrow-circle-o-down:before {
  content: "\F01A"; }

.fa-arrow-circle-o-up:before {
  content: "\F01B"; }

.fa-inbox:before {
  content: "\F01C"; }

.fa-play-circle-o:before {
  content: "\F01D"; }

.fa-rotate-right:before,
.fa-repeat:before {
  content: "\F01E"; }

.fa-refresh:before {
  content: "\F021"; }

.fa-list-alt:before {
  content: "\F022"; }

.fa-lock:before {
  content: "\F023"; }

.fa-flag:before {
  content: "\F024"; }

.fa-headphones:before {
  content: "\F025"; }

.fa-volume-off:before {
  content: "\F026"; }

.fa-volume-down:before {
  content: "\F027"; }

.fa-volume-up:before {
  content: "\F028"; }

.fa-qrcode:before {
  content: "\F029"; }

.fa-barcode:before {
  content: "\F02A"; }

.fa-tag:before {
  content: "\F02B"; }

.fa-tags:before {
  content: "\F02C"; }

.fa-book:before {
  content: "\F02D"; }

.fa-bookmark:before {
  content: "\F02E"; }

.fa-print:before {
  content: "\F02F"; }

.fa-camera:before {
  content: "\F030"; }

.fa-font:before {
  content: "\F031"; }

.fa-bold:before {
  content: "\F032"; }

.fa-italic:before {
  content: "\F033"; }

.fa-text-height:before {
  content: "\F034"; }

.fa-text-width:before {
  content: "\F035"; }

.fa-align-left:before {
  content: "\F036"; }

.fa-align-center:before {
  content: "\F037"; }

.fa-align-right:before {
  content: "\F038"; }

.fa-align-justify:before {
  content: "\F039"; }

.fa-list:before {
  content: "\F03A"; }

.fa-dedent:before,
.fa-outdent:before {
  content: "\F03B"; }

.fa-indent:before {
  content: "\F03C"; }

.fa-video-camera:before {
  content: "\F03D"; }

.fa-photo:before,
.fa-image:before,
.fa-picture-o:before {
  content: "\F03E"; }

.fa-pencil:before {
  content: "\F040"; }

.fa-map-marker:before {
  content: "\F041"; }

.fa-adjust:before {
  content: "\F042"; }

.fa-tint:before {
  content: "\F043"; }

.fa-edit:before,
.fa-pencil-square-o:before {
  content: "\F044"; }

.fa-share-square-o:before {
  content: "\F045"; }

.fa-check-square-o:before {
  content: "\F046"; }

.fa-arrows:before {
  content: "\F047"; }

.fa-step-backward:before {
  content: "\F048"; }

.fa-fast-backward:before {
  content: "\F049"; }

.fa-backward:before {
  content: "\F04A"; }

.fa-play:before {
  content: "\F04B"; }

.fa-pause:before {
  content: "\F04C"; }

.fa-stop:before {
  content: "\F04D"; }

.fa-forward:before {
  content: "\F04E"; }

.fa-fast-forward:before {
  content: "\F050"; }

.fa-step-forward:before {
  content: "\F051"; }

.fa-eject:before {
  content: "\F052"; }

.fa-chevron-left:before {
  content: "\F053"; }

.fa-chevron-right:before {
  content: "\F054"; }

.fa-plus-circle:before {
  content: "\F055"; }

.fa-minus-circle:before {
  content: "\F056"; }

.fa-times-circle:before {
  content: "\F057"; }

.fa-check-circle:before {
  content: "\F058"; }

.fa-question-circle:before {
  content: "\F059"; }

.fa-info-circle:before {
  content: "\F05A"; }

.fa-crosshairs:before {
  content: "\F05B"; }

.fa-times-circle-o:before {
  content: "\F05C"; }

.fa-check-circle-o:before {
  content: "\F05D"; }

.fa-ban:before {
  content: "\F05E"; }

.fa-arrow-left:before {
  content: "\F060"; }

.fa-arrow-right:before {
  content: "\F061"; }

.fa-arrow-up:before {
  content: "\F062"; }

.fa-arrow-down:before {
  content: "\F063"; }

.fa-mail-forward:before,
.fa-share:before {
  content: "\F064"; }

.fa-expand:before {
  content: "\F065"; }

.fa-compress:before {
  content: "\F066"; }

.fa-plus:before {
  content: "\F067"; }

.fa-minus:before {
  content: "\F068"; }

.fa-asterisk:before {
  content: "\F069"; }

.fa-exclamation-circle:before {
  content: "\F06A"; }

.fa-gift:before {
  content: "\F06B"; }

.fa-leaf:before {
  content: "\F06C"; }

.fa-fire:before {
  content: "\F06D"; }

.fa-eye:before {
  content: "\F06E"; }

.fa-eye-slash:before {
  content: "\F070"; }

.fa-warning:before,
.fa-exclamation-triangle:before {
  content: "\F071"; }

.fa-plane:before {
  content: "\F072"; }

.fa-calendar:before {
  content: "\F073"; }

.fa-random:before {
  content: "\F074"; }

.fa-comment:before {
  content: "\F075"; }

.fa-magnet:before {
  content: "\F076"; }

.fa-chevron-up:before {
  content: "\F077"; }

.fa-chevron-down:before {
  content: "\F078"; }

.fa-retweet:before {
  content: "\F079"; }

.fa-shopping-cart:before {
  content: "\F07A"; }

.fa-folder:before {
  content: "\F07B"; }

.fa-folder-open:before {
  content: "\F07C"; }

.fa-arrows-v:before {
  content: "\F07D"; }

.fa-arrows-h:before {
  content: "\F07E"; }

.fa-bar-chart-o:before,
.fa-bar-chart:before {
  content: "\F080"; }

.fa-twitter-square:before {
  content: "\F081"; }

.fa-facebook-square:before {
  content: "\F082"; }

.fa-camera-retro:before {
  content: "\F083"; }

.fa-key:before {
  content: "\F084"; }

.fa-gears:before,
.fa-cogs:before {
  content: "\F085"; }

.fa-comments:before {
  content: "\F086"; }

.fa-thumbs-o-up:before {
  content: "\F087"; }

.fa-thumbs-o-down:before {
  content: "\F088"; }

.fa-star-half:before {
  content: "\F089"; }

.fa-heart-o:before {
  content: "\F08A"; }

.fa-sign-out:before {
  content: "\F08B"; }

.fa-linkedin-square:before {
  content: "\F08C"; }

.fa-thumb-tack:before {
  content: "\F08D"; }

.fa-external-link:before {
  content: "\F08E"; }

.fa-sign-in:before {
  content: "\F090"; }

.fa-trophy:before {
  content: "\F091"; }

.fa-github-square:before {
  content: "\F092"; }

.fa-upload:before {
  content: "\F093"; }

.fa-lemon-o:before {
  content: "\F094"; }

.fa-phone:before {
  content: "\F095"; }

.fa-square-o:before {
  content: "\F096"; }

.fa-bookmark-o:before {
  content: "\F097"; }

.fa-phone-square:before {
  content: "\F098"; }

.fa-twitter:before {
  content: "\F099"; }

.fa-facebook-f:before,
.fa-facebook:before {
  content: "\F09A"; }

.fa-github:before {
  content: "\F09B"; }

.fa-unlock:before {
  content: "\F09C"; }

.fa-credit-card:before {
  content: "\F09D"; }

.fa-feed:before,
.fa-rss:before {
  content: "\F09E"; }

.fa-hdd-o:before {
  content: "\F0A0"; }

.fa-bullhorn:before {
  content: "\F0A1"; }

.fa-bell:before {
  content: "\F0F3"; }

.fa-certificate:before {
  content: "\F0A3"; }

.fa-hand-o-right:before {
  content: "\F0A4"; }

.fa-hand-o-left:before {
  content: "\F0A5"; }

.fa-hand-o-up:before {
  content: "\F0A6"; }

.fa-hand-o-down:before {
  content: "\F0A7"; }

.fa-arrow-circle-left:before {
  content: "\F0A8"; }

.fa-arrow-circle-right:before {
  content: "\F0A9"; }

.fa-arrow-circle-up:before {
  content: "\F0AA"; }

.fa-arrow-circle-down:before {
  content: "\F0AB"; }

.fa-globe:before {
  content: "\F0AC"; }

.fa-wrench:before {
  content: "\F0AD"; }

.fa-tasks:before {
  content: "\F0AE"; }

.fa-filter:before {
  content: "\F0B0"; }

.fa-briefcase:before {
  content: "\F0B1"; }

.fa-arrows-alt:before {
  content: "\F0B2"; }

.fa-group:before,
.fa-users:before {
  content: "\F0C0"; }

.fa-chain:before,
.fa-link:before {
  content: "\F0C1"; }

.fa-cloud:before {
  content: "\F0C2"; }

.fa-flask:before {
  content: "\F0C3"; }

.fa-cut:before,
.fa-scissors:before {
  content: "\F0C4"; }

.fa-copy:before,
.fa-files-o:before {
  content: "\F0C5"; }

.fa-paperclip:before {
  content: "\F0C6"; }

.fa-save:before,
.fa-floppy-o:before {
  content: "\F0C7"; }

.fa-square:before {
  content: "\F0C8"; }

.fa-navicon:before,
.fa-reorder:before,
.fa-bars:before {
  content: "\F0C9"; }

.fa-list-ul:before {
  content: "\F0CA"; }

.fa-list-ol:before {
  content: "\F0CB"; }

.fa-strikethrough:before {
  content: "\F0CC"; }

.fa-underline:before {
  content: "\F0CD"; }

.fa-table:before {
  content: "\F0CE"; }

.fa-magic:before {
  content: "\F0D0"; }

.fa-truck:before {
  content: "\F0D1"; }

.fa-pinterest:before {
  content: "\F0D2"; }

.fa-pinterest-square:before {
  content: "\F0D3"; }

.fa-google-plus-square:before {
  content: "\F0D4"; }

.fa-google-plus:before {
  content: "\F0D5"; }

.fa-money:before {
  content: "\F0D6"; }

.fa-caret-down:before {
  content: "\F0D7"; }

.fa-caret-up:before {
  content: "\F0D8"; }

.fa-caret-left:before {
  content: "\F0D9"; }

.fa-caret-right:before {
  content: "\F0DA"; }

.fa-columns:before {
  content: "\F0DB"; }

.fa-unsorted:before,
.fa-sort:before {
  content: "\F0DC"; }

.fa-sort-down:before,
.fa-sort-desc:before {
  content: "\F0DD"; }

.fa-sort-up:before,
.fa-sort-asc:before {
  content: "\F0DE"; }

.fa-envelope:before {
  content: "\F0E0"; }

.fa-linkedin:before {
  content: "\F0E1"; }

.fa-rotate-left:before,
.fa-undo:before {
  content: "\F0E2"; }

.fa-legal:before,
.fa-gavel:before {
  content: "\F0E3"; }

.fa-dashboard:before,
.fa-tachometer:before {
  content: "\F0E4"; }

.fa-comment-o:before {
  content: "\F0E5"; }

.fa-comments-o:before {
  content: "\F0E6"; }

.fa-flash:before,
.fa-bolt:before {
  content: "\F0E7"; }

.fa-sitemap:before {
  content: "\F0E8"; }

.fa-umbrella:before {
  content: "\F0E9"; }

.fa-paste:before,
.fa-clipboard:before {
  content: "\F0EA"; }

.fa-lightbulb-o:before {
  content: "\F0EB"; }

.fa-exchange:before {
  content: "\F0EC"; }

.fa-cloud-download:before {
  content: "\F0ED"; }

.fa-cloud-upload:before {
  content: "\F0EE"; }

.fa-user-md:before {
  content: "\F0F0"; }

.fa-stethoscope:before {
  content: "\F0F1"; }

.fa-suitcase:before {
  content: "\F0F2"; }

.fa-bell-o:before {
  content: "\F0A2"; }

.fa-coffee:before {
  content: "\F0F4"; }

.fa-cutlery:before {
  content: "\F0F5"; }

.fa-file-text-o:before {
  content: "\F0F6"; }

.fa-building-o:before {
  content: "\F0F7"; }

.fa-hospital-o:before {
  content: "\F0F8"; }

.fa-ambulance:before {
  content: "\F0F9"; }

.fa-medkit:before {
  content: "\F0FA"; }

.fa-fighter-jet:before {
  content: "\F0FB"; }

.fa-beer:before {
  content: "\F0FC"; }

.fa-h-square:before {
  content: "\F0FD"; }

.fa-plus-square:before {
  content: "\F0FE"; }

.fa-angle-double-left:before {
  content: "\F100"; }

.fa-angle-double-right:before {
  content: "\F101"; }

.fa-angle-double-up:before {
  content: "\F102"; }

.fa-angle-double-down:before {
  content: "\F103"; }

.fa-angle-left:before {
  content: "\F104"; }

.fa-angle-right:before {
  content: "\F105"; }

.fa-angle-up:before {
  content: "\F106"; }

.fa-angle-down:before {
  content: "\F107"; }

.fa-desktop:before {
  content: "\F108"; }

.fa-laptop:before {
  content: "\F109"; }

.fa-tablet:before {
  content: "\F10A"; }

.fa-mobile-phone:before,
.fa-mobile:before {
  content: "\F10B"; }

.fa-circle-o:before {
  content: "\F10C"; }

.fa-quote-left:before {
  content: "\F10D"; }

.fa-quote-right:before {
  content: "\F10E"; }

.fa-spinner:before {
  content: "\F110"; }

.fa-circle:before {
  content: "\F111"; }

.fa-mail-reply:before,
.fa-reply:before {
  content: "\F112"; }

.fa-github-alt:before {
  content: "\F113"; }

.fa-folder-o:before {
  content: "\F114"; }

.fa-folder-open-o:before {
  content: "\F115"; }

.fa-smile-o:before {
  content: "\F118"; }

.fa-frown-o:before {
  content: "\F119"; }

.fa-meh-o:before {
  content: "\F11A"; }

.fa-gamepad:before {
  content: "\F11B"; }

.fa-keyboard-o:before {
  content: "\F11C"; }

.fa-flag-o:before {
  content: "\F11D"; }

.fa-flag-checkered:before {
  content: "\F11E"; }

.fa-terminal:before {
  content: "\F120"; }

.fa-code:before {
  content: "\F121"; }

.fa-mail-reply-all:before,
.fa-reply-all:before {
  content: "\F122"; }

.fa-star-half-empty:before,
.fa-star-half-full:before,
.fa-star-half-o:before {
  content: "\F123"; }

.fa-location-arrow:before {
  content: "\F124"; }

.fa-crop:before {
  content: "\F125"; }

.fa-code-fork:before {
  content: "\F126"; }

.fa-unlink:before,
.fa-chain-broken:before {
  content: "\F127"; }

.fa-question:before {
  content: "\F128"; }

.fa-info:before {
  content: "\F129"; }

.fa-exclamation:before {
  content: "\F12A"; }

.fa-superscript:before {
  content: "\F12B"; }

.fa-subscript:before {
  content: "\F12C"; }

.fa-eraser:before {
  content: "\F12D"; }

.fa-puzzle-piece:before {
  content: "\F12E"; }

.fa-microphone:before {
  content: "\F130"; }

.fa-microphone-slash:before {
  content: "\F131"; }

.fa-shield:before {
  content: "\F132"; }

.fa-calendar-o:before {
  content: "\F133"; }

.fa-fire-extinguisher:before {
  content: "\F134"; }

.fa-rocket:before {
  content: "\F135"; }

.fa-maxcdn:before {
  content: "\F136"; }

.fa-chevron-circle-left:before {
  content: "\F137"; }

.fa-chevron-circle-right:before {
  content: "\F138"; }

.fa-chevron-circle-up:before {
  content: "\F139"; }

.fa-chevron-circle-down:before {
  content: "\F13A"; }

.fa-html5:before {
  content: "\F13B"; }

.fa-css3:before {
  content: "\F13C"; }

.fa-anchor:before {
  content: "\F13D"; }

.fa-unlock-alt:before {
  content: "\F13E"; }

.fa-bullseye:before {
  content: "\F140"; }

.fa-ellipsis-h:before {
  content: "\F141"; }

.fa-ellipsis-v:before {
  content: "\F142"; }

.fa-rss-square:before {
  content: "\F143"; }

.fa-play-circle:before {
  content: "\F144"; }

.fa-ticket:before {
  content: "\F145"; }

.fa-minus-square:before {
  content: "\F146"; }

.fa-minus-square-o:before {
  content: "\F147"; }

.fa-level-up:before {
  content: "\F148"; }

.fa-level-down:before {
  content: "\F149"; }

.fa-check-square:before {
  content: "\F14A"; }

.fa-pencil-square:before {
  content: "\F14B"; }

.fa-external-link-square:before {
  content: "\F14C"; }

.fa-share-square:before {
  content: "\F14D"; }

.fa-compass:before {
  content: "\F14E"; }

.fa-toggle-down:before,
.fa-caret-square-o-down:before {
  content: "\F150"; }

.fa-toggle-up:before,
.fa-caret-square-o-up:before {
  content: "\F151"; }

.fa-toggle-right:before,
.fa-caret-square-o-right:before {
  content: "\F152"; }

.fa-euro:before,
.fa-eur:before {
  content: "\F153"; }

.fa-gbp:before {
  content: "\F154"; }

.fa-dollar:before,
.fa-usd:before {
  content: "\F155"; }

.fa-rupee:before,
.fa-inr:before {
  content: "\F156"; }

.fa-cny:before,
.fa-rmb:before,
.fa-yen:before,
.fa-jpy:before {
  content: "\F157"; }

.fa-ruble:before,
.fa-rouble:before,
.fa-rub:before {
  content: "\F158"; }

.fa-won:before,
.fa-krw:before {
  content: "\F159"; }

.fa-bitcoin:before,
.fa-btc:before {
  content: "\F15A"; }

.fa-file:before {
  content: "\F15B"; }

.fa-file-text:before {
  content: "\F15C"; }

.fa-sort-alpha-asc:before {
  content: "\F15D"; }

.fa-sort-alpha-desc:before {
  content: "\F15E"; }

.fa-sort-amount-asc:before {
  content: "\F160"; }

.fa-sort-amount-desc:before {
  content: "\F161"; }

.fa-sort-numeric-asc:before {
  content: "\F162"; }

.fa-sort-numeric-desc:before {
  content: "\F163"; }

.fa-thumbs-up:before {
  content: "\F164"; }

.fa-thumbs-down:before {
  content: "\F165"; }

.fa-youtube-square:before {
  content: "\F166"; }

.fa-youtube:before {
  content: "\F167"; }

.fa-xing:before {
  content: "\F168"; }

.fa-xing-square:before {
  content: "\F169"; }

.fa-youtube-play:before {
  content: "\F16A"; }

.fa-dropbox:before {
  content: "\F16B"; }

.fa-stack-overflow:before {
  content: "\F16C"; }

.fa-instagram:before {
  content: "\F16D"; }

.fa-flickr:before {
  content: "\F16E"; }

.fa-adn:before {
  content: "\F170"; }

.fa-bitbucket:before {
  content: "\F171"; }

.fa-bitbucket-square:before {
  content: "\F172"; }

.fa-tumblr:before {
  content: "\F173"; }

.fa-tumblr-square:before {
  content: "\F174"; }

.fa-long-arrow-down:before {
  content: "\F175"; }

.fa-long-arrow-up:before {
  content: "\F176"; }

.fa-long-arrow-left:before {
  content: "\F177"; }

.fa-long-arrow-right:before {
  content: "\F178"; }

.fa-apple:before {
  content: "\F179"; }

.fa-windows:before {
  content: "\F17A"; }

.fa-android:before {
  content: "\F17B"; }

.fa-linux:before {
  content: "\F17C"; }

.fa-dribbble:before {
  content: "\F17D"; }

.fa-skype:before {
  content: "\F17E"; }

.fa-foursquare:before {
  content: "\F180"; }

.fa-trello:before {
  content: "\F181"; }

.fa-female:before {
  content: "\F182"; }

.fa-male:before {
  content: "\F183"; }

.fa-gittip:before,
.fa-gratipay:before {
  content: "\F184"; }

.fa-sun-o:before {
  content: "\F185"; }

.fa-moon-o:before {
  content: "\F186"; }

.fa-archive:before {
  content: "\F187"; }

.fa-bug:before {
  content: "\F188"; }

.fa-vk:before {
  content: "\F189"; }

.fa-weibo:before {
  content: "\F18A"; }

.fa-renren:before {
  content: "\F18B"; }

.fa-pagelines:before {
  content: "\F18C"; }

.fa-stack-exchange:before {
  content: "\F18D"; }

.fa-arrow-circle-o-right:before {
  content: "\F18E"; }

.fa-arrow-circle-o-left:before {
  content: "\F190"; }

.fa-toggle-left:before,
.fa-caret-square-o-left:before {
  content: "\F191"; }

.fa-dot-circle-o:before {
  content: "\F192"; }

.fa-wheelchair:before {
  content: "\F193"; }

.fa-vimeo-square:before {
  content: "\F194"; }

.fa-turkish-lira:before,
.fa-try:before {
  content: "\F195"; }

.fa-plus-square-o:before {
  content: "\F196"; }

.fa-space-shuttle:before {
  content: "\F197"; }

.fa-slack:before {
  content: "\F198"; }

.fa-envelope-square:before {
  content: "\F199"; }

.fa-wordpress:before {
  content: "\F19A"; }

.fa-openid:before {
  content: "\F19B"; }

.fa-institution:before,
.fa-bank:before,
.fa-university:before {
  content: "\F19C"; }

.fa-mortar-board:before,
.fa-graduation-cap:before {
  content: "\F19D"; }

.fa-yahoo:before {
  content: "\F19E"; }

.fa-google:before {
  content: "\F1A0"; }

.fa-reddit:before {
  content: "\F1A1"; }

.fa-reddit-square:before {
  content: "\F1A2"; }

.fa-stumbleupon-circle:before {
  content: "\F1A3"; }

.fa-stumbleupon:before {
  content: "\F1A4"; }

.fa-delicious:before {
  content: "\F1A5"; }

.fa-digg:before {
  content: "\F1A6"; }

.fa-pied-piper-pp:before {
  content: "\F1A7"; }

.fa-pied-piper-alt:before {
  content: "\F1A8"; }

.fa-drupal:before {
  content: "\F1A9"; }

.fa-joomla:before {
  content: "\F1AA"; }

.fa-language:before {
  content: "\F1AB"; }

.fa-fax:before {
  content: "\F1AC"; }

.fa-building:before {
  content: "\F1AD"; }

.fa-child:before {
  content: "\F1AE"; }

.fa-paw:before {
  content: "\F1B0"; }

.fa-spoon:before {
  content: "\F1B1"; }

.fa-cube:before {
  content: "\F1B2"; }

.fa-cubes:before {
  content: "\F1B3"; }

.fa-behance:before {
  content: "\F1B4"; }

.fa-behance-square:before {
  content: "\F1B5"; }

.fa-steam:before {
  content: "\F1B6"; }

.fa-steam-square:before {
  content: "\F1B7"; }

.fa-recycle:before {
  content: "\F1B8"; }

.fa-automobile:before,
.fa-car:before {
  content: "\F1B9"; }

.fa-cab:before,
.fa-taxi:before {
  content: "\F1BA"; }

.fa-tree:before {
  content: "\F1BB"; }

.fa-spotify:before {
  content: "\F1BC"; }

.fa-deviantart:before {
  content: "\F1BD"; }

.fa-soundcloud:before {
  content: "\F1BE"; }

.fa-database:before {
  content: "\F1C0"; }

.fa-file-pdf-o:before {
  content: "\F1C1"; }

.fa-file-word-o:before {
  content: "\F1C2"; }

.fa-file-excel-o:before {
  content: "\F1C3"; }

.fa-file-powerpoint-o:before {
  content: "\F1C4"; }

.fa-file-photo-o:before,
.fa-file-picture-o:before,
.fa-file-image-o:before {
  content: "\F1C5"; }

.fa-file-zip-o:before,
.fa-file-archive-o:before {
  content: "\F1C6"; }

.fa-file-sound-o:before,
.fa-file-audio-o:before {
  content: "\F1C7"; }

.fa-file-movie-o:before,
.fa-file-video-o:before {
  content: "\F1C8"; }

.fa-file-code-o:before {
  content: "\F1C9"; }

.fa-vine:before {
  content: "\F1CA"; }

.fa-codepen:before {
  content: "\F1CB"; }

.fa-jsfiddle:before {
  content: "\F1CC"; }

.fa-life-bouy:before,
.fa-life-buoy:before,
.fa-life-saver:before,
.fa-support:before,
.fa-life-ring:before {
  content: "\F1CD"; }

.fa-circle-o-notch:before {
  content: "\F1CE"; }

.fa-ra:before,
.fa-resistance:before,
.fa-rebel:before {
  content: "\F1D0"; }

.fa-ge:before,
.fa-empire:before {
  content: "\F1D1"; }

.fa-git-square:before {
  content: "\F1D2"; }

.fa-git:before {
  content: "\F1D3"; }

.fa-y-combinator-square:before,
.fa-yc-square:before,
.fa-hacker-news:before {
  content: "\F1D4"; }

.fa-tencent-weibo:before {
  content: "\F1D5"; }

.fa-qq:before {
  content: "\F1D6"; }

.fa-wechat:before,
.fa-weixin:before {
  content: "\F1D7"; }

.fa-send:before,
.fa-paper-plane:before {
  content: "\F1D8"; }

.fa-send-o:before,
.fa-paper-plane-o:before {
  content: "\F1D9"; }

.fa-history:before {
  content: "\F1DA"; }

.fa-circle-thin:before {
  content: "\F1DB"; }

.fa-header:before {
  content: "\F1DC"; }

.fa-paragraph:before {
  content: "\F1DD"; }

.fa-sliders:before {
  content: "\F1DE"; }

.fa-share-alt:before {
  content: "\F1E0"; }

.fa-share-alt-square:before {
  content: "\F1E1"; }

.fa-bomb:before {
  content: "\F1E2"; }

.fa-soccer-ball-o:before,
.fa-futbol-o:before {
  content: "\F1E3"; }

.fa-tty:before {
  content: "\F1E4"; }

.fa-binoculars:before {
  content: "\F1E5"; }

.fa-plug:before {
  content: "\F1E6"; }

.fa-slideshare:before {
  content: "\F1E7"; }

.fa-twitch:before {
  content: "\F1E8"; }

.fa-yelp:before {
  content: "\F1E9"; }

.fa-newspaper-o:before {
  content: "\F1EA"; }

.fa-wifi:before {
  content: "\F1EB"; }

.fa-calculator:before {
  content: "\F1EC"; }

.fa-paypal:before {
  content: "\F1ED"; }

.fa-google-wallet:before {
  content: "\F1EE"; }

.fa-cc-visa:before {
  content: "\F1F0"; }

.fa-cc-mastercard:before {
  content: "\F1F1"; }

.fa-cc-discover:before {
  content: "\F1F2"; }

.fa-cc-amex:before {
  content: "\F1F3"; }

.fa-cc-paypal:before {
  content: "\F1F4"; }

.fa-cc-stripe:before {
  content: "\F1F5"; }

.fa-bell-slash:before {
  content: "\F1F6"; }

.fa-bell-slash-o:before {
  content: "\F1F7"; }

.fa-trash:before {
  content: "\F1F8"; }

.fa-copyright:before {
  content: "\F1F9"; }

.fa-at:before {
  content: "\F1FA"; }

.fa-eyedropper:before {
  content: "\F1FB"; }

.fa-paint-brush:before {
  content: "\F1FC"; }

.fa-birthday-cake:before {
  content: "\F1FD"; }

.fa-area-chart:before {
  content: "\F1FE"; }

.fa-pie-chart:before {
  content: "\F200"; }

.fa-line-chart:before {
  content: "\F201"; }

.fa-lastfm:before {
  content: "\F202"; }

.fa-lastfm-square:before {
  content: "\F203"; }

.fa-toggle-off:before {
  content: "\F204"; }

.fa-toggle-on:before {
  content: "\F205"; }

.fa-bicycle:before {
  content: "\F206"; }

.fa-bus:before {
  content: "\F207"; }

.fa-ioxhost:before {
  content: "\F208"; }

.fa-angellist:before {
  content: "\F209"; }

.fa-cc:before {
  content: "\F20A"; }

.fa-shekel:before,
.fa-sheqel:before,
.fa-ils:before {
  content: "\F20B"; }

.fa-meanpath:before {
  content: "\F20C"; }

.fa-buysellads:before {
  content: "\F20D"; }

.fa-connectdevelop:before {
  content: "\F20E"; }

.fa-dashcube:before {
  content: "\F210"; }

.fa-forumbee:before {
  content: "\F211"; }

.fa-leanpub:before {
  content: "\F212"; }

.fa-sellsy:before {
  content: "\F213"; }

.fa-shirtsinbulk:before {
  content: "\F214"; }

.fa-simplybuilt:before {
  content: "\F215"; }

.fa-skyatlas:before {
  content: "\F216"; }

.fa-cart-plus:before {
  content: "\F217"; }

.fa-cart-arrow-down:before {
  content: "\F218"; }

.fa-diamond:before {
  content: "\F219"; }

.fa-ship:before {
  content: "\F21A"; }

.fa-user-secret:before {
  content: "\F21B"; }

.fa-motorcycle:before {
  content: "\F21C"; }

.fa-street-view:before {
  content: "\F21D"; }

.fa-heartbeat:before {
  content: "\F21E"; }

.fa-venus:before {
  content: "\F221"; }

.fa-mars:before {
  content: "\F222"; }

.fa-mercury:before {
  content: "\F223"; }

.fa-intersex:before,
.fa-transgender:before {
  content: "\F224"; }

.fa-transgender-alt:before {
  content: "\F225"; }

.fa-venus-double:before {
  content: "\F226"; }

.fa-mars-double:before {
  content: "\F227"; }

.fa-venus-mars:before {
  content: "\F228"; }

.fa-mars-stroke:before {
  content: "\F229"; }

.fa-mars-stroke-v:before {
  content: "\F22A"; }

.fa-mars-stroke-h:before {
  content: "\F22B"; }

.fa-neuter:before {
  content: "\F22C"; }

.fa-genderless:before {
  content: "\F22D"; }

.fa-facebook-official:before {
  content: "\F230"; }

.fa-pinterest-p:before {
  content: "\F231"; }

.fa-whatsapp:before {
  content: "\F232"; }

.fa-server:before {
  content: "\F233"; }

.fa-user-plus:before {
  content: "\F234"; }

.fa-user-times:before {
  content: "\F235"; }

.fa-hotel:before,
.fa-bed:before {
  content: "\F236"; }

.fa-viacoin:before {
  content: "\F237"; }

.fa-train:before {
  content: "\F238"; }

.fa-subway:before {
  content: "\F239"; }

.fa-medium:before {
  content: "\F23A"; }

.fa-yc:before,
.fa-y-combinator:before {
  content: "\F23B"; }

.fa-optin-monster:before {
  content: "\F23C"; }

.fa-opencart:before {
  content: "\F23D"; }

.fa-expeditedssl:before {
  content: "\F23E"; }

.fa-battery-4:before,
.fa-battery:before,
.fa-battery-full:before {
  content: "\F240"; }

.fa-battery-3:before,
.fa-battery-three-quarters:before {
  content: "\F241"; }

.fa-battery-2:before,
.fa-battery-half:before {
  content: "\F242"; }

.fa-battery-1:before,
.fa-battery-quarter:before {
  content: "\F243"; }

.fa-battery-0:before,
.fa-battery-empty:before {
  content: "\F244"; }

.fa-mouse-pointer:before {
  content: "\F245"; }

.fa-i-cursor:before {
  content: "\F246"; }

.fa-object-group:before {
  content: "\F247"; }

.fa-object-ungroup:before {
  content: "\F248"; }

.fa-sticky-note:before {
  content: "\F249"; }

.fa-sticky-note-o:before {
  content: "\F24A"; }

.fa-cc-jcb:before {
  content: "\F24B"; }

.fa-cc-diners-club:before {
  content: "\F24C"; }

.fa-clone:before {
  content: "\F24D"; }

.fa-balance-scale:before {
  content: "\F24E"; }

.fa-hourglass-o:before {
  content: "\F250"; }

.fa-hourglass-1:before,
.fa-hourglass-start:before {
  content: "\F251"; }

.fa-hourglass-2:before,
.fa-hourglass-half:before {
  content: "\F252"; }

.fa-hourglass-3:before,
.fa-hourglass-end:before {
  content: "\F253"; }

.fa-hourglass:before {
  content: "\F254"; }

.fa-hand-grab-o:before,
.fa-hand-rock-o:before {
  content: "\F255"; }

.fa-hand-stop-o:before,
.fa-hand-paper-o:before {
  content: "\F256"; }

.fa-hand-scissors-o:before {
  content: "\F257"; }

.fa-hand-lizard-o:before {
  content: "\F258"; }

.fa-hand-spock-o:before {
  content: "\F259"; }

.fa-hand-pointer-o:before {
  content: "\F25A"; }

.fa-hand-peace-o:before {
  content: "\F25B"; }

.fa-trademark:before {
  content: "\F25C"; }

.fa-registered:before {
  content: "\F25D"; }

.fa-creative-commons:before {
  content: "\F25E"; }

.fa-gg:before {
  content: "\F260"; }

.fa-gg-circle:before {
  content: "\F261"; }

.fa-tripadvisor:before {
  content: "\F262"; }

.fa-odnoklassniki:before {
  content: "\F263"; }

.fa-odnoklassniki-square:before {
  content: "\F264"; }

.fa-get-pocket:before {
  content: "\F265"; }

.fa-wikipedia-w:before {
  content: "\F266"; }

.fa-safari:before {
  content: "\F267"; }

.fa-chrome:before {
  content: "\F268"; }

.fa-firefox:before {
  content: "\F269"; }

.fa-opera:before {
  content: "\F26A"; }

.fa-internet-explorer:before {
  content: "\F26B"; }

.fa-tv:before,
.fa-television:before {
  content: "\F26C"; }

.fa-contao:before {
  content: "\F26D"; }

.fa-500px:before {
  content: "\F26E"; }

.fa-amazon:before {
  content: "\F270"; }

.fa-calendar-plus-o:before {
  content: "\F271"; }

.fa-calendar-minus-o:before {
  content: "\F272"; }

.fa-calendar-times-o:before {
  content: "\F273"; }

.fa-calendar-check-o:before {
  content: "\F274"; }

.fa-industry:before {
  content: "\F275"; }

.fa-map-pin:before {
  content: "\F276"; }

.fa-map-signs:before {
  content: "\F277"; }

.fa-map-o:before {
  content: "\F278"; }

.fa-map:before {
  content: "\F279"; }

.fa-commenting:before {
  content: "\F27A"; }

.fa-commenting-o:before {
  content: "\F27B"; }

.fa-houzz:before {
  content: "\F27C"; }

.fa-vimeo:before {
  content: "\F27D"; }

.fa-black-tie:before {
  content: "\F27E"; }

.fa-fonticons:before {
  content: "\F280"; }

.fa-reddit-alien:before {
  content: "\F281"; }

.fa-edge:before {
  content: "\F282"; }

.fa-credit-card-alt:before {
  content: "\F283"; }

.fa-codiepie:before {
  content: "\F284"; }

.fa-modx:before {
  content: "\F285"; }

.fa-fort-awesome:before {
  content: "\F286"; }

.fa-usb:before {
  content: "\F287"; }

.fa-product-hunt:before {
  content: "\F288"; }

.fa-mixcloud:before {
  content: "\F289"; }

.fa-scribd:before {
  content: "\F28A"; }

.fa-pause-circle:before {
  content: "\F28B"; }

.fa-pause-circle-o:before {
  content: "\F28C"; }

.fa-stop-circle:before {
  content: "\F28D"; }

.fa-stop-circle-o:before {
  content: "\F28E"; }

.fa-shopping-bag:before {
  content: "\F290"; }

.fa-shopping-basket:before {
  content: "\F291"; }

.fa-hashtag:before {
  content: "\F292"; }

.fa-bluetooth:before {
  content: "\F293"; }

.fa-bluetooth-b:before {
  content: "\F294"; }

.fa-percent:before {
  content: "\F295"; }

.fa-gitlab:before {
  content: "\F296"; }

.fa-wpbeginner:before {
  content: "\F297"; }

.fa-wpforms:before {
  content: "\F298"; }

.fa-envira:before {
  content: "\F299"; }

.fa-universal-access:before {
  content: "\F29A"; }

.fa-wheelchair-alt:before {
  content: "\F29B"; }

.fa-question-circle-o:before {
  content: "\F29C"; }

.fa-blind:before {
  content: "\F29D"; }

.fa-audio-description:before {
  content: "\F29E"; }

.fa-volume-control-phone:before {
  content: "\F2A0"; }

.fa-braille:before {
  content: "\F2A1"; }

.fa-assistive-listening-systems:before {
  content: "\F2A2"; }

.fa-asl-interpreting:before,
.fa-american-sign-language-interpreting:before {
  content: "\F2A3"; }

.fa-deafness:before,
.fa-hard-of-hearing:before,
.fa-deaf:before {
  content: "\F2A4"; }

.fa-glide:before {
  content: "\F2A5"; }

.fa-glide-g:before {
  content: "\F2A6"; }

.fa-signing:before,
.fa-sign-language:before {
  content: "\F2A7"; }

.fa-low-vision:before {
  content: "\F2A8"; }

.fa-viadeo:before {
  content: "\F2A9"; }

.fa-viadeo-square:before {
  content: "\F2AA"; }

.fa-snapchat:before {
  content: "\F2AB"; }

.fa-snapchat-ghost:before {
  content: "\F2AC"; }

.fa-snapchat-square:before {
  content: "\F2AD"; }

.fa-pied-piper:before {
  content: "\F2AE"; }

.fa-first-order:before {
  content: "\F2B0"; }

.fa-yoast:before {
  content: "\F2B1"; }

.fa-themeisle:before {
  content: "\F2B2"; }

.fa-google-plus-circle:before,
.fa-google-plus-official:before {
  content: "\F2B3"; }

.fa-fa:before,
.fa-font-awesome:before {
  content: "\F2B4"; }

.fa-handshake-o:before {
  content: "\F2B5"; }

.fa-envelope-open:before {
  content: "\F2B6"; }

.fa-envelope-open-o:before {
  content: "\F2B7"; }

.fa-linode:before {
  content: "\F2B8"; }

.fa-address-book:before {
  content: "\F2B9"; }

.fa-address-book-o:before {
  content: "\F2BA"; }

.fa-vcard:before,
.fa-address-card:before {
  content: "\F2BB"; }

.fa-vcard-o:before,
.fa-address-card-o:before {
  content: "\F2BC"; }

.fa-user-circle:before {
  content: "\F2BD"; }

.fa-user-circle-o:before {
  content: "\F2BE"; }

.fa-user-o:before {
  content: "\F2C0"; }

.fa-id-badge:before {
  content: "\F2C1"; }

.fa-drivers-license:before,
.fa-id-card:before {
  content: "\F2C2"; }

.fa-drivers-license-o:before,
.fa-id-card-o:before {
  content: "\F2C3"; }

.fa-quora:before {
  content: "\F2C4"; }

.fa-free-code-camp:before {
  content: "\F2C5"; }

.fa-telegram:before {
  content: "\F2C6"; }

.fa-thermometer-4:before,
.fa-thermometer:before,
.fa-thermometer-full:before {
  content: "\F2C7"; }

.fa-thermometer-3:before,
.fa-thermometer-three-quarters:before {
  content: "\F2C8"; }

.fa-thermometer-2:before,
.fa-thermometer-half:before {
  content: "\F2C9"; }

.fa-thermometer-1:before,
.fa-thermometer-quarter:before {
  content: "\F2CA"; }

.fa-thermometer-0:before,
.fa-thermometer-empty:before {
  content: "\F2CB"; }

.fa-shower:before {
  content: "\F2CC"; }

.fa-bathtub:before,
.fa-s15:before,
.fa-bath:before {
  content: "\F2CD"; }

.fa-podcast:before {
  content: "\F2CE"; }

.fa-window-maximize:before {
  content: "\F2D0"; }

.fa-window-minimize:before {
  content: "\F2D1"; }

.fa-window-restore:before {
  content: "\F2D2"; }

.fa-times-rectangle:before,
.fa-window-close:before {
  content: "\F2D3"; }

.fa-times-rectangle-o:before,
.fa-window-close-o:before {
  content: "\F2D4"; }

.fa-bandcamp:before {
  content: "\F2D5"; }

.fa-grav:before {
  content: "\F2D6"; }

.fa-etsy:before {
  content: "\F2D7"; }

.fa-imdb:before {
  content: "\F2D8"; }

.fa-ravelry:before {
  content: "\F2D9"; }

.fa-eercast:before {
  content: "\F2DA"; }

.fa-microchip:before {
  content: "\F2DB"; }

.fa-snowflake-o:before {
  content: "\F2DC"; }

.fa-superpowers:before {
  content: "\F2DD"; }

.fa-wpexplorer:before {
  content: "\F2DE"; }

.fa-meetup:before {
  content: "\F2E0"; }

.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.sr-only-focusable:active,
.sr-only-focusable:focus {
  position: static;
  width: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  clip: auto; }
/*!
 * Bootstrap v3.0.0
 *
 * Copyright 2013 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world by @mdo and @fat.
 */
/*! normalize.css v2.1.0 | MIT License | git.io/normalize */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
nav,
section,
summary {
  display: block; }

audio,
canvas,
video {
  display: inline-block; }

audio:not([controls]) {
  display: none;
  height: 0; }

[hidden] {
  display: none; }

html {
  font-family: sans-serif;
  -webkit-text-size-adjust: 100%;
  -ms-text-size-adjust: 100%; }

body {
  margin: 0; }

a:focus {
  outline: thin dotted; }

a:active,
a:hover {
  outline: 0; }

h1 {
  margin: 0.67em 0;
  font-size: 2em; }

abbr[title] {
  border-bottom: 1px dotted; }

b,
strong {
  font-weight: bold; }

dfn {
  font-style: italic; }

hr {
  height: 0;
  -moz-box-sizing: content-box;
  box-sizing: content-box; }

mark {
  color: #000;
  background: #ff0; }

code,
kbd,
pre,
samp {
  font-family: monospace, serif;
  font-size: 1em; }

pre {
  white-space: pre-wrap; }

q {
  quotes: "\201C" "\201D" "\2018" "\2019"; }

small {
  font-size: 80%; }

sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline; }

sup {
  top: -0.5em; }

sub {
  bottom: -0.25em; }

img {
  border: 0; }

svg:not(:root) {
  overflow: hidden; }

figure {
  margin: 0; }

fieldset {
  padding: 0.35em 0.625em 0.75em;
  margin: 0 2px;
  border: 1px solid #c0c0c0; }

legend {
  padding: 0;
  border: 0; }

button,
input,
select,
textarea {
  margin: 0;
  font-family: inherit;
  font-size: 100%; }

button,
input {
  line-height: normal; }

button,
select {
  text-transform: none; }

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  cursor: pointer;
  -webkit-appearance: button; }

button[disabled],
html input[disabled] {
  cursor: default; }

input[type="checkbox"],
input[type="radio"] {
  padding: 0;
  box-sizing: border-box; }

input[type="search"] {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  -webkit-appearance: textfield; }

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none; }

button::-moz-focus-inner,
input::-moz-focus-inner {
  padding: 0;
  border: 0; }

textarea {
  overflow: auto;
  vertical-align: top; }

table {
  border-collapse: collapse;
  border-spacing: 0; }

@media print {
  * {
    color: #000 !important;
    text-shadow: none !important;
    background: transparent !important;
    box-shadow: none !important; }
  a,
  a:visited {
    text-decoration: underline; }
  a[href]:after {
    content: " (" attr(href) ")"; }
  abbr[title]:after {
    content: " (" attr(title) ")"; }
  .ir a:after,
  a[href^="javascript:"]:after,
  a[href^="#"]:after {
    content: ""; }
  pre,
  blockquote {
    border: 1px solid #999;
    page-break-inside: avoid; }
  thead {
    display: table-header-group; }
  tr,
  img {
    page-break-inside: avoid; }
  img {
    max-width: 100% !important; }
  @page {
    margin: 2cm .5cm; }
  p,
  h2,
  h3 {
    orphans: 3;
    widows: 3; }
  h2,
  h3 {
    page-break-after: avoid; }
  .navbar {
    display: none; }
  .table td,
  .table th {
    background-color: #fff !important; }
  .btn > .caret,
  .dropup > .btn > .caret {
    border-top-color: #000 !important; }
  .label {
    border: 1px solid #000; }
  .table {
    border-collapse: collapse !important; }
  .table-bordered th,
  .table-bordered td {
    border: 1px solid #ddd !important; } }

*,
*:before,
*:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box; }

html {
  font-size: 62.5%;
  -webkit-tap-highlight-color: transparent; }

body {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  line-height: 1.428571429;
  color: #333333;
  background-color: #ffffff; }

input,
button,
select,
textarea {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit; }

a {
  color: #428bca;
  text-decoration: none; }

a:hover,
a:focus {
  color: #2a6496;
  text-decoration: underline; }

a:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px; }

img {
  vertical-align: middle; }

.img-responsive {
  display: block;
  height: auto;
  max-width: 100%; }

.img-rounded {
  border-radius: 6px; }

.img-thumbnail {
  display: inline-block;
  height: auto;
  max-width: 100%;
  padding: 4px;
  line-height: 1.428571429;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-radius: 4px;
  -webkit-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out; }

.img-circle {
  border-radius: 50%; }

hr {
  margin-top: 20px;
  margin-bottom: 20px;
  border: 0;
  border-top: 1px solid #eeeeee; }

.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0 0 0 0);
  border: 0; }

p {
  margin: 0 0 10px; }

.lead {
  margin-bottom: 20px;
  font-size: 16.099999999999998px;
  font-weight: 200;
  line-height: 1.4; }

@media (min-width: 768px) {
  .lead {
    font-size: 21px; } }

small,
.small {
  font-size: 85%; }

cite {
  font-style: normal; }

.text-muted {
  color: #999999; }

.text-primary {
  color: #428bca; }

.text-primary:hover {
  color: #3071a9; }

.text-warning {
  color: #c09853; }

.text-warning:hover {
  color: #a47e3c; }

.text-danger {
  color: #b94a48; }

.text-danger:hover {
  color: #953b39; }

.text-success {
  color: #468847; }

.text-success:hover {
  color: #356635; }

.text-info {
  color: #3a87ad; }

.text-info:hover {
  color: #2d6987; }

.text-left {
  text-align: left; }

.text-right {
  text-align: right; }

.text-center {
  text-align: center; }

h1,
h2,
h3,
h4,
h5,
h6,
.h1,
.h2,
.h3,
.h4,
.h5,
.h6 {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-weight: 500;
  line-height: 1.1;
  color: inherit; }

h1 small,
h2 small,
h3 small,
h4 small,
h5 small,
h6 small,
.h1 small,
.h2 small,
.h3 small,
.h4 small,
.h5 small,
.h6 small {
  font-weight: normal;
  line-height: 1;
  color: #999999; }

h1,
h2,
h3 {
  margin-top: 20px;
  margin-bottom: 10px; }

h1 small,
h2 small,
h3 small {
  font-size: 65%; }

h4,
h5,
h6 {
  margin-top: 10px;
  margin-bottom: 10px; }

h4 small,
h5 small,
h6 small {
  font-size: 75%; }

h1,
.h1 {
  font-size: 36px; }

h2,
.h2 {
  font-size: 30px; }

h3,
.h3 {
  font-size: 24px; }

h4,
.h4 {
  font-size: 18px; }

h5,
.h5 {
  font-size: 14px; }

h6,
.h6 {
  font-size: 12px; }

.page-header {
  padding-bottom: 9px;
  margin: 40px 0 20px;
  border-bottom: 1px solid #eeeeee; }

ul,
ol {
  margin-top: 0;
  margin-bottom: 10px; }

ul ul,
ol ul,
ul ol,
ol ol {
  margin-bottom: 0; }

.list-unstyled {
  padding-left: 0;
  list-style: none; }

.list-inline {
  padding-left: 0;
  list-style: none; }

.list-inline > li {
  display: inline-block;
  padding-right: 5px;
  padding-left: 5px; }

dl {
  margin-bottom: 20px; }

dt,
dd {
  line-height: 1.428571429; }

dt {
  font-weight: bold; }

dd {
  margin-left: 0; }

@media (min-width: 768px) {
  .dl-horizontal dt {
    float: left;
    width: 160px;
    overflow: hidden;
    clear: left;
    text-align: right;
    text-overflow: ellipsis;
    white-space: nowrap; }
  .dl-horizontal dd {
    margin-left: 180px; }
  .dl-horizontal dd:before,
  .dl-horizontal dd:after {
    display: table;
    content: " "; }
  .dl-horizontal dd:after {
    clear: both; }
  .dl-horizontal dd:before,
  .dl-horizontal dd:after {
    display: table;
    content: " "; }
  .dl-horizontal dd:after {
    clear: both; } }

abbr[title],
abbr[data-original-title] {
  cursor: help;
  border-bottom: 1px dotted #999999; }

abbr.initialism {
  font-size: 90%;
  text-transform: uppercase; }

blockquote {
  padding: 10px 20px;
  margin: 0 0 20px;
  border-left: 5px solid #eeeeee; }

blockquote p {
  font-size: 17.5px;
  font-weight: 300;
  line-height: 1.25; }

blockquote p:last-child {
  margin-bottom: 0; }

blockquote small {
  display: block;
  line-height: 1.428571429;
  color: #999999; }

blockquote small:before {
  content: '\2014   \A0'; }

blockquote.pull-right {
  padding-right: 15px;
  padding-left: 0;
  border-right: 5px solid #eeeeee;
  border-left: 0; }

blockquote.pull-right p,
blockquote.pull-right small {
  text-align: right; }

blockquote.pull-right small:before {
  content: ''; }

blockquote.pull-right small:after {
  content: '\A0   \2014'; }

q:before,
q:after,
blockquote:before,
blockquote:after {
  content: ""; }

address {
  display: block;
  margin-bottom: 20px;
  font-style: normal;
  line-height: 1.428571429; }

code,
pre {
  font-family: Monaco, Menlo, Consolas, "Courier New", monospace; }

code {
  padding: 2px 4px;
  font-size: 90%;
  color: #c7254e;
  white-space: nowrap;
  background-color: #f9f2f4;
  border-radius: 4px; }

pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 1.428571429;
  color: #333333;
  word-break: break-all;
  word-wrap: break-word;
  background-color: #f5f5f5;
  border: 1px solid #cccccc;
  border-radius: 4px; }

pre.prettyprint {
  margin-bottom: 20px; }

pre code {
  padding: 0;
  font-size: inherit;
  color: inherit;
  white-space: pre-wrap;
  background-color: transparent;
  border: 0; }

.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll; }

.container {
  padding-right: 15px;
  padding-left: 15px;
  margin-right: auto;
  margin-left: auto; }

.container:before,
.container:after {
  display: table;
  content: " "; }

.container:after {
  clear: both; }

.container:before,
.container:after {
  display: table;
  content: " "; }

.container:after {
  clear: both; }

.row {
  margin-right: -15px;
  margin-left: -15px; }

.row:before,
.row:after {
  display: table;
  content: " "; }

.row:after {
  clear: both; }

.row:before,
.row:after {
  display: table;
  content: " "; }

.row:after {
  clear: both; }

.col-xs-1,
.col-xs-2,
.col-xs-3,
.col-xs-4,
.col-xs-5,
.col-xs-6,
.col-xs-7,
.col-xs-8,
.col-xs-9,
.col-xs-10,
.col-xs-11,
.col-xs-12,
.col-sm-1,
.col-sm-2,
.col-sm-3,
.col-sm-4,
.col-sm-5,
.col-sm-6,
.col-sm-7,
.col-sm-8,
.col-sm-9,
.col-sm-10,
.col-sm-11,
.col-sm-12,
.col-md-1,
.col-md-2,
.col-md-3,
.col-md-4,
.col-md-5,
.col-md-6,
.col-md-7,
.col-md-8,
.col-md-9,
.col-md-10,
.col-md-11,
.col-md-12,
.col-lg-1,
.col-lg-2,
.col-lg-3,
.col-lg-4,
.col-lg-5,
.col-lg-6,
.col-lg-7,
.col-lg-8,
.col-lg-9,
.col-lg-10,
.col-lg-11,
.col-lg-12 {
  position: relative;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px; }

.col-xs-1,
.col-xs-2,
.col-xs-3,
.col-xs-4,
.col-xs-5,
.col-xs-6,
.col-xs-7,
.col-xs-8,
.col-xs-9,
.col-xs-10,
.col-xs-11 {
  float: left; }

.col-xs-1 {
  width: 8.333333333333332%; }

.col-xs-2 {
  width: 16.666666666666664%; }

.col-xs-3 {
  width: 25%; }

.col-xs-4 {
  width: 33.33333333333333%; }

.col-xs-5 {
  width: 41.66666666666667%; }

.col-xs-6 {
  width: 50%; }

.col-xs-7 {
  width: 58.333333333333336%; }

.col-xs-8 {
  width: 66.66666666666666%; }

.col-xs-9 {
  width: 75%; }

.col-xs-10 {
  width: 83.33333333333334%; }

.col-xs-11 {
  width: 91.66666666666666%; }

.col-xs-12 {
  width: 100%; }

@media (min-width: 768px) {
  .container {
    width: 750px; }
  .col-sm-1,
  .col-sm-2,
  .col-sm-3,
  .col-sm-4,
  .col-sm-5,
  .col-sm-6,
  .col-sm-7,
  .col-sm-8,
  .col-sm-9,
  .col-sm-10,
  .col-sm-11 {
    float: left; }
  .col-sm-1 {
    width: 8.333333333333332%; }
  .col-sm-2 {
    width: 16.666666666666664%; }
  .col-sm-3 {
    width: 25%; }
  .col-sm-4 {
    width: 33.33333333333333%; }
  .col-sm-5 {
    width: 41.66666666666667%; }
  .col-sm-6 {
    width: 50%; }
  .col-sm-7 {
    width: 58.333333333333336%; }
  .col-sm-8 {
    width: 66.66666666666666%; }
  .col-sm-9 {
    width: 75%; }
  .col-sm-10 {
    width: 83.33333333333334%; }
  .col-sm-11 {
    width: 91.66666666666666%; }
  .col-sm-12 {
    width: 100%; }
  .col-sm-push-1 {
    left: 8.333333333333332%; }
  .col-sm-push-2 {
    left: 16.666666666666664%; }
  .col-sm-push-3 {
    left: 25%; }
  .col-sm-push-4 {
    left: 33.33333333333333%; }
  .col-sm-push-5 {
    left: 41.66666666666667%; }
  .col-sm-push-6 {
    left: 50%; }
  .col-sm-push-7 {
    left: 58.333333333333336%; }
  .col-sm-push-8 {
    left: 66.66666666666666%; }
  .col-sm-push-9 {
    left: 75%; }
  .col-sm-push-10 {
    left: 83.33333333333334%; }
  .col-sm-push-11 {
    left: 91.66666666666666%; }
  .col-sm-pull-1 {
    right: 8.333333333333332%; }
  .col-sm-pull-2 {
    right: 16.666666666666664%; }
  .col-sm-pull-3 {
    right: 25%; }
  .col-sm-pull-4 {
    right: 33.33333333333333%; }
  .col-sm-pull-5 {
    right: 41.66666666666667%; }
  .col-sm-pull-6 {
    right: 50%; }
  .col-sm-pull-7 {
    right: 58.333333333333336%; }
  .col-sm-pull-8 {
    right: 66.66666666666666%; }
  .col-sm-pull-9 {
    right: 75%; }
  .col-sm-pull-10 {
    right: 83.33333333333334%; }
  .col-sm-pull-11 {
    right: 91.66666666666666%; }
  .col-sm-offset-1 {
    margin-left: 8.333333333333332%; }
  .col-sm-offset-2 {
    margin-left: 16.666666666666664%; }
  .col-sm-offset-3 {
    margin-left: 25%; }
  .col-sm-offset-4 {
    margin-left: 33.33333333333333%; }
  .col-sm-offset-5 {
    margin-left: 41.66666666666667%; }
  .col-sm-offset-6 {
    margin-left: 50%; }
  .col-sm-offset-7 {
    margin-left: 58.333333333333336%; }
  .col-sm-offset-8 {
    margin-left: 66.66666666666666%; }
  .col-sm-offset-9 {
    margin-left: 75%; }
  .col-sm-offset-10 {
    margin-left: 83.33333333333334%; }
  .col-sm-offset-11 {
    margin-left: 91.66666666666666%; } }

@media (min-width: 992px) {
  .container {
    width: 970px; }
  .col-md-1,
  .col-md-2,
  .col-md-3,
  .col-md-4,
  .col-md-5,
  .col-md-6,
  .col-md-7,
  .col-md-8,
  .col-md-9,
  .col-md-10,
  .col-md-11 {
    float: left; }
  .col-md-1 {
    width: 8.333333333333332%; }
  .col-md-2 {
    width: 16.666666666666664%; }
  .col-md-3 {
    width: 25%; }
  .col-md-4 {
    width: 33.33333333333333%; }
  .col-md-5 {
    width: 41.66666666666667%; }
  .col-md-6 {
    width: 50%; }
  .col-md-7 {
    width: 58.333333333333336%; }
  .col-md-8 {
    width: 66.66666666666666%; }
  .col-md-9 {
    width: 75%; }
  .col-md-10 {
    width: 83.33333333333334%; }
  .col-md-11 {
    width: 91.66666666666666%; }
  .col-md-12 {
    width: 100%; }
  .col-md-push-0 {
    left: auto; }
  .col-md-push-1 {
    left: 8.333333333333332%; }
  .col-md-push-2 {
    left: 16.666666666666664%; }
  .col-md-push-3 {
    left: 25%; }
  .col-md-push-4 {
    left: 33.33333333333333%; }
  .col-md-push-5 {
    left: 41.66666666666667%; }
  .col-md-push-6 {
    left: 50%; }
  .col-md-push-7 {
    left: 58.333333333333336%; }
  .col-md-push-8 {
    left: 66.66666666666666%; }
  .col-md-push-9 {
    left: 75%; }
  .col-md-push-10 {
    left: 83.33333333333334%; }
  .col-md-push-11 {
    left: 91.66666666666666%; }
  .col-md-pull-0 {
    right: auto; }
  .col-md-pull-1 {
    right: 8.333333333333332%; }
  .col-md-pull-2 {
    right: 16.666666666666664%; }
  .col-md-pull-3 {
    right: 25%; }
  .col-md-pull-4 {
    right: 33.33333333333333%; }
  .col-md-pull-5 {
    right: 41.66666666666667%; }
  .col-md-pull-6 {
    right: 50%; }
  .col-md-pull-7 {
    right: 58.333333333333336%; }
  .col-md-pull-8 {
    right: 66.66666666666666%; }
  .col-md-pull-9 {
    right: 75%; }
  .col-md-pull-10 {
    right: 83.33333333333334%; }
  .col-md-pull-11 {
    right: 91.66666666666666%; }
  .col-md-offset-0 {
    margin-left: 0; }
  .col-md-offset-1 {
    margin-left: 8.333333333333332%; }
  .col-md-offset-2 {
    margin-left: 16.666666666666664%; }
  .col-md-offset-3 {
    margin-left: 25%; }
  .col-md-offset-4 {
    margin-left: 33.33333333333333%; }
  .col-md-offset-5 {
    margin-left: 41.66666666666667%; }
  .col-md-offset-6 {
    margin-left: 50%; }
  .col-md-offset-7 {
    margin-left: 58.333333333333336%; }
  .col-md-offset-8 {
    margin-left: 66.66666666666666%; }
  .col-md-offset-9 {
    margin-left: 75%; }
  .col-md-offset-10 {
    margin-left: 83.33333333333334%; }
  .col-md-offset-11 {
    margin-left: 91.66666666666666%; } }

@media (min-width: 1200px) {
  .container {
    width: 1170px; }
  .col-lg-1,
  .col-lg-2,
  .col-lg-3,
  .col-lg-4,
  .col-lg-5,
  .col-lg-6,
  .col-lg-7,
  .col-lg-8,
  .col-lg-9,
  .col-lg-10,
  .col-lg-11 {
    float: left; }
  .col-lg-1 {
    width: 8.333333333333332%; }
  .col-lg-2 {
    width: 16.666666666666664%; }
  .col-lg-3 {
    width: 25%; }
  .col-lg-4 {
    width: 33.33333333333333%; }
  .col-lg-5 {
    width: 41.66666666666667%; }
  .col-lg-6 {
    width: 50%; }
  .col-lg-7 {
    width: 58.333333333333336%; }
  .col-lg-8 {
    width: 66.66666666666666%; }
  .col-lg-9 {
    width: 75%; }
  .col-lg-10 {
    width: 83.33333333333334%; }
  .col-lg-11 {
    width: 91.66666666666666%; }
  .col-lg-12 {
    width: 100%; }
  .col-lg-push-0 {
    left: auto; }
  .col-lg-push-1 {
    left: 8.333333333333332%; }
  .col-lg-push-2 {
    left: 16.666666666666664%; }
  .col-lg-push-3 {
    left: 25%; }
  .col-lg-push-4 {
    left: 33.33333333333333%; }
  .col-lg-push-5 {
    left: 41.66666666666667%; }
  .col-lg-push-6 {
    left: 50%; }
  .col-lg-push-7 {
    left: 58.333333333333336%; }
  .col-lg-push-8 {
    left: 66.66666666666666%; }
  .col-lg-push-9 {
    left: 75%; }
  .col-lg-push-10 {
    left: 83.33333333333334%; }
  .col-lg-push-11 {
    left: 91.66666666666666%; }
  .col-lg-pull-0 {
    right: auto; }
  .col-lg-pull-1 {
    right: 8.333333333333332%; }
  .col-lg-pull-2 {
    right: 16.666666666666664%; }
  .col-lg-pull-3 {
    right: 25%; }
  .col-lg-pull-4 {
    right: 33.33333333333333%; }
  .col-lg-pull-5 {
    right: 41.66666666666667%; }
  .col-lg-pull-6 {
    right: 50%; }
  .col-lg-pull-7 {
    right: 58.333333333333336%; }
  .col-lg-pull-8 {
    right: 66.66666666666666%; }
  .col-lg-pull-9 {
    right: 75%; }
  .col-lg-pull-10 {
    right: 83.33333333333334%; }
  .col-lg-pull-11 {
    right: 91.66666666666666%; }
  .col-lg-offset-0 {
    margin-left: 0; }
  .col-lg-offset-1 {
    margin-left: 8.333333333333332%; }
  .col-lg-offset-2 {
    margin-left: 16.666666666666664%; }
  .col-lg-offset-3 {
    margin-left: 25%; }
  .col-lg-offset-4 {
    margin-left: 33.33333333333333%; }
  .col-lg-offset-5 {
    margin-left: 41.66666666666667%; }
  .col-lg-offset-6 {
    margin-left: 50%; }
  .col-lg-offset-7 {
    margin-left: 58.333333333333336%; }
  .col-lg-offset-8 {
    margin-left: 66.66666666666666%; }
  .col-lg-offset-9 {
    margin-left: 75%; }
  .col-lg-offset-10 {
    margin-left: 83.33333333333334%; }
  .col-lg-offset-11 {
    margin-left: 91.66666666666666%; } }

table {
  max-width: 100%;
  background-color: transparent; }

th {
  text-align: left; }

.table {
  width: 100%;
  margin-bottom: 20px; }

.table > thead > tr > th,
.table > tbody > tr > th,
.table > tfoot > tr > th,
.table > thead > tr > td,
.table > tbody > tr > td,
.table > tfoot > tr > td {
  padding: 8px;
  line-height: 1.428571429;
  vertical-align: top;
  border-top: 1px solid #dddddd; }

.table > thead > tr > th {
  vertical-align: bottom;
  border-bottom: 2px solid #dddddd; }

.table > caption + thead > tr:first-child > th,
.table > colgroup + thead > tr:first-child > th,
.table > thead:first-child > tr:first-child > th,
.table > caption + thead > tr:first-child > td,
.table > colgroup + thead > tr:first-child > td,
.table > thead:first-child > tr:first-child > td {
  border-top: 0; }

.table > tbody + tbody {
  border-top: 2px solid #dddddd; }

.table .table {
  background-color: #ffffff; }

.table-condensed > thead > tr > th,
.table-condensed > tbody > tr > th,
.table-condensed > tfoot > tr > th,
.table-condensed > thead > tr > td,
.table-condensed > tbody > tr > td,
.table-condensed > tfoot > tr > td {
  padding: 5px; }

.table-bordered {
  border: 1px solid #dddddd; }

.table-bordered > thead > tr > th,
.table-bordered > tbody > tr > th,
.table-bordered > tfoot > tr > th,
.table-bordered > thead > tr > td,
.table-bordered > tbody > tr > td,
.table-bordered > tfoot > tr > td {
  border: 1px solid #dddddd; }

.table-bordered > thead > tr > th,
.table-bordered > thead > tr > td {
  border-bottom-width: 2px; }

.table-striped > tbody > tr:nth-child(odd) > td,
.table-striped > tbody > tr:nth-child(odd) > th {
  background-color: #f9f9f9; }

.table-hover > tbody > tr:hover > td,
.table-hover > tbody > tr:hover > th {
  background-color: #f5f5f5; }

table col[class*="col-"] {
  display: table-column;
  float: none; }

table td[class*="col-"],
table th[class*="col-"] {
  display: table-cell;
  float: none; }

.table > thead > tr > td.active,
.table > tbody > tr > td.active,
.table > tfoot > tr > td.active,
.table > thead > tr > th.active,
.table > tbody > tr > th.active,
.table > tfoot > tr > th.active,
.table > thead > tr.active > td,
.table > tbody > tr.active > td,
.table > tfoot > tr.active > td,
.table > thead > tr.active > th,
.table > tbody > tr.active > th,
.table > tfoot > tr.active > th {
  background-color: #f5f5f5; }

.table > thead > tr > td.success,
.table > tbody > tr > td.success,
.table > tfoot > tr > td.success,
.table > thead > tr > th.success,
.table > tbody > tr > th.success,
.table > tfoot > tr > th.success,
.table > thead > tr.success > td,
.table > tbody > tr.success > td,
.table > tfoot > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr.success > th,
.table > tfoot > tr.success > th {
  background-color: #dff0d8;
  border-color: #d6e9c6; }

.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr.success:hover > th {
  background-color: #d0e9c6;
  border-color: #c9e2b3; }

.table > thead > tr > td.danger,
.table > tbody > tr > td.danger,
.table > tfoot > tr > td.danger,
.table > thead > tr > th.danger,
.table > tbody > tr > th.danger,
.table > tfoot > tr > th.danger,
.table > thead > tr.danger > td,
.table > tbody > tr.danger > td,
.table > tfoot > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr.danger > th,
.table > tfoot > tr.danger > th {
  background-color: #f2dede;
  border-color: #ebccd1; }

.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr.danger:hover > th {
  background-color: #ebcccc;
  border-color: #e4b9c0; }

.table > thead > tr > td.warning,
.table > tbody > tr > td.warning,
.table > tfoot > tr > td.warning,
.table > thead > tr > th.warning,
.table > tbody > tr > th.warning,
.table > tfoot > tr > th.warning,
.table > thead > tr.warning > td,
.table > tbody > tr.warning > td,
.table > tfoot > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr.warning > th,
.table > tfoot > tr.warning > th {
  background-color: #fcf8e3;
  border-color: #faebcc; }

.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr.warning:hover > th {
  background-color: #faf2cc;
  border-color: #f7e1b5; }

@media (max-width: 768px) {
  .table-responsive {
    width: 100%;
    margin-bottom: 15px;
    overflow-x: scroll;
    overflow-y: hidden;
    border: 1px solid #dddddd;
    -ms-overflow-style: -ms-autohiding-scrollbar;
    -webkit-overflow-scrolling: touch; }
  .table-responsive > .table {
    margin-bottom: 0; }
  .table-responsive > .table > thead > tr > th,
  .table-responsive > .table > tbody > tr > th,
  .table-responsive > .table > tfoot > tr > th,
  .table-responsive > .table > thead > tr > td,
  .table-responsive > .table > tbody > tr > td,
  .table-responsive > .table > tfoot > tr > td {
    white-space: nowrap; }
  .table-responsive > .table-bordered {
    border: 0; }
  .table-responsive > .table-bordered > thead > tr > th:first-child,
  .table-responsive > .table-bordered > tbody > tr > th:first-child,
  .table-responsive > .table-bordered > tfoot > tr > th:first-child,
  .table-responsive > .table-bordered > thead > tr > td:first-child,
  .table-responsive > .table-bordered > tbody > tr > td:first-child,
  .table-responsive > .table-bordered > tfoot > tr > td:first-child {
    border-left: 0; }
  .table-responsive > .table-bordered > thead > tr > th:last-child,
  .table-responsive > .table-bordered > tbody > tr > th:last-child,
  .table-responsive > .table-bordered > tfoot > tr > th:last-child,
  .table-responsive > .table-bordered > thead > tr > td:last-child,
  .table-responsive > .table-bordered > tbody > tr > td:last-child,
  .table-responsive > .table-bordered > tfoot > tr > td:last-child {
    border-right: 0; }
  .table-responsive > .table-bordered > tbody > tr:last-child > th,
  .table-responsive > .table-bordered > tfoot > tr:last-child > th,
  .table-responsive > .table-bordered > tbody > tr:last-child > td,
  .table-responsive > .table-bordered > tfoot > tr:last-child > td {
    border-bottom: 0; } }

fieldset {
  padding: 0;
  margin: 0;
  border: 0; }

legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 21px;
  line-height: inherit;
  color: #333333;
  border: 0;
  border-bottom: 1px solid #e5e5e5; }

label {
  display: inline-block;
  margin-bottom: 5px;
  font-weight: bold; }

input[type="search"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box; }

input[type="radio"],
input[type="checkbox"] {
  margin: 4px 0 0;
  margin-top: 1px \9;
  /* IE8-9 */
  line-height: normal; }

input[type="file"] {
  display: block; }

select[multiple],
select[size] {
  height: auto; }

select optgroup {
  font-family: inherit;
  font-size: inherit;
  font-style: inherit; }

input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px; }

input[type="number"]::-webkit-outer-spin-button,
input[type="number"]::-webkit-inner-spin-button {
  height: auto; }

output {
  display: block;
  padding-top: 7px;
  font-size: 14px;
  line-height: 1.428571429;
  color: #555555;
  vertical-align: middle; }

.form-control:-moz-placeholder {
  color: #999999; }

.form-control::-moz-placeholder {
  color: #999999; }

.form-control:-ms-input-placeholder {
  color: #999999; }

.form-control::-webkit-input-placeholder {
  color: #999999; }

.form-control {
  display: block;
  width: 100%;
  height: 34px;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.428571429;
  color: #555555;
  vertical-align: middle;
  background-color: #ffffff;
  background-image: none;
  border: 1px solid #cccccc;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s; }

.form-control:focus {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6); }

.form-control[disabled],
.form-control[readonly],
fieldset[disabled] .form-control {
  cursor: not-allowed;
  background-color: #eeeeee; }

textarea.form-control {
  height: auto; }

.form-group {
  margin-bottom: 15px; }

.radio,
.checkbox {
  display: block;
  min-height: 20px;
  padding-left: 20px;
  margin-top: 10px;
  margin-bottom: 10px;
  vertical-align: middle; }

.radio label,
.checkbox label {
  display: inline;
  margin-bottom: 0;
  font-weight: normal;
  cursor: pointer; }

.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
  float: left;
  margin-left: -20px; }

.radio + .radio,
.checkbox + .checkbox {
  margin-top: -5px; }

.radio-inline,
.checkbox-inline {
  display: inline-block;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: normal;
  vertical-align: middle;
  cursor: pointer; }

.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 10px; }

input[type="radio"][disabled],
input[type="checkbox"][disabled],
.radio[disabled],
.radio-inline[disabled],
.checkbox[disabled],
.checkbox-inline[disabled],
fieldset[disabled] input[type="radio"],
fieldset[disabled] input[type="checkbox"],
fieldset[disabled] .radio,
fieldset[disabled] .radio-inline,
fieldset[disabled] .checkbox,
fieldset[disabled] .checkbox-inline {
  cursor: not-allowed; }

.input-sm {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

select.input-sm {
  height: 30px;
  line-height: 30px; }

textarea.input-sm {
  height: auto; }

.input-lg {
  height: 45px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33;
  border-radius: 6px; }

select.input-lg {
  height: 45px;
  line-height: 45px; }

textarea.input-lg {
  height: auto; }

.has-warning .help-block,
.has-warning .control-label {
  color: #c09853; }

.has-warning .form-control {
  border-color: #c09853;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }

.has-warning .form-control:focus {
  border-color: #a47e3c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #dbc59e;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #dbc59e; }

.has-warning .input-group-addon {
  color: #c09853;
  background-color: #fcf8e3;
  border-color: #c09853; }

.has-error .help-block,
.has-error .control-label {
  color: #b94a48; }

.has-error .form-control {
  border-color: #b94a48;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }

.has-error .form-control:focus {
  border-color: #953b39;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #d59392;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #d59392; }

.has-error .input-group-addon {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #b94a48; }

.has-success .help-block,
.has-success .control-label {
  color: #468847; }

.has-success .form-control {
  border-color: #468847;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }

.has-success .form-control:focus {
  border-color: #356635;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7aba7b;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7aba7b; }

.has-success .input-group-addon {
  color: #468847;
  background-color: #dff0d8;
  border-color: #468847; }

.form-control-static {
  padding-top: 7px;
  margin-bottom: 0; }

.help-block {
  display: block;
  margin-top: 5px;
  margin-bottom: 10px;
  color: #737373; }

@media (min-width: 768px) {
  .form-inline .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle; }
  .form-inline .form-control {
    display: inline-block; }
  .form-inline .radio,
  .form-inline .checkbox {
    display: inline-block;
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0; }
  .form-inline .radio input[type="radio"],
  .form-inline .checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0; } }

.form-horizontal .control-label,
.form-horizontal .radio,
.form-horizontal .checkbox,
.form-horizontal .radio-inline,
.form-horizontal .checkbox-inline {
  padding-top: 7px;
  margin-top: 0;
  margin-bottom: 0; }

.form-horizontal .form-group {
  margin-right: -15px;
  margin-left: -15px; }

.form-horizontal .form-group:before,
.form-horizontal .form-group:after {
  display: table;
  content: " "; }

.form-horizontal .form-group:after {
  clear: both; }

.form-horizontal .form-group:before,
.form-horizontal .form-group:after {
  display: table;
  content: " "; }

.form-horizontal .form-group:after {
  clear: both; }

@media (min-width: 768px) {
  .form-horizontal .control-label {
    text-align: right; } }

.btn {
  display: inline-block;
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: normal;
  line-height: 1.428571429;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  -o-user-select: none;
  user-select: none; }

.btn:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px; }

.btn:hover,
.btn:focus {
  color: #333333;
  text-decoration: none; }

.btn:active,
.btn.active {
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }

.btn.disabled,
.btn[disabled],
fieldset[disabled] .btn {
  pointer-events: none;
  cursor: not-allowed;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
  box-shadow: none; }

.btn-default {
  color: #333333;
  background-color: #ffffff;
  border-color: #cccccc; }

.btn-default:hover,
.btn-default:focus,
.btn-default:active,
.btn-default.active,
.open .dropdown-toggle.btn-default {
  color: #333333;
  background-color: #ebebeb;
  border-color: #adadad; }

.btn-default:active,
.btn-default.active,
.open .dropdown-toggle.btn-default {
  background-image: none; }

.btn-default.disabled,
.btn-default[disabled],
fieldset[disabled] .btn-default,
.btn-default.disabled:hover,
.btn-default[disabled]:hover,
fieldset[disabled] .btn-default:hover,
.btn-default.disabled:focus,
.btn-default[disabled]:focus,
fieldset[disabled] .btn-default:focus,
.btn-default.disabled:active,
.btn-default[disabled]:active,
fieldset[disabled] .btn-default:active,
.btn-default.disabled.active,
.btn-default[disabled].active,
fieldset[disabled] .btn-default.active {
  background-color: #ffffff;
  border-color: #cccccc; }

.btn-primary {
  color: #ffffff;
  background-color: #428bca;
  border-color: #357ebd; }

.btn-primary:hover,
.btn-primary:focus,
.btn-primary:active,
.btn-primary.active,
.open .dropdown-toggle.btn-primary {
  color: #ffffff;
  background-color: #3276b1;
  border-color: #285e8e; }

.btn-primary:active,
.btn-primary.active,
.open .dropdown-toggle.btn-primary {
  background-image: none; }

.btn-primary.disabled,
.btn-primary[disabled],
fieldset[disabled] .btn-primary,
.btn-primary.disabled:hover,
.btn-primary[disabled]:hover,
fieldset[disabled] .btn-primary:hover,
.btn-primary.disabled:focus,
.btn-primary[disabled]:focus,
fieldset[disabled] .btn-primary:focus,
.btn-primary.disabled:active,
.btn-primary[disabled]:active,
fieldset[disabled] .btn-primary:active,
.btn-primary.disabled.active,
.btn-primary[disabled].active,
fieldset[disabled] .btn-primary.active {
  background-color: #428bca;
  border-color: #357ebd; }

.btn-warning {
  color: #ffffff;
  background-color: #f0ad4e;
  border-color: #eea236; }

.btn-warning:hover,
.btn-warning:focus,
.btn-warning:active,
.btn-warning.active,
.open .dropdown-toggle.btn-warning {
  color: #ffffff;
  background-color: #ed9c28;
  border-color: #d58512; }

.btn-warning:active,
.btn-warning.active,
.open .dropdown-toggle.btn-warning {
  background-image: none; }

.btn-warning.disabled,
.btn-warning[disabled],
fieldset[disabled] .btn-warning,
.btn-warning.disabled:hover,
.btn-warning[disabled]:hover,
fieldset[disabled] .btn-warning:hover,
.btn-warning.disabled:focus,
.btn-warning[disabled]:focus,
fieldset[disabled] .btn-warning:focus,
.btn-warning.disabled:active,
.btn-warning[disabled]:active,
fieldset[disabled] .btn-warning:active,
.btn-warning.disabled.active,
.btn-warning[disabled].active,
fieldset[disabled] .btn-warning.active {
  background-color: #f0ad4e;
  border-color: #eea236; }

.btn-danger {
  color: #ffffff;
  background-color: #d9534f;
  border-color: #d43f3a; }

.btn-danger:hover,
.btn-danger:focus,
.btn-danger:active,
.btn-danger.active,
.open .dropdown-toggle.btn-danger {
  color: #ffffff;
  background-color: #d2322d;
  border-color: #ac2925; }

.btn-danger:active,
.btn-danger.active,
.open .dropdown-toggle.btn-danger {
  background-image: none; }

.btn-danger.disabled,
.btn-danger[disabled],
fieldset[disabled] .btn-danger,
.btn-danger.disabled:hover,
.btn-danger[disabled]:hover,
fieldset[disabled] .btn-danger:hover,
.btn-danger.disabled:focus,
.btn-danger[disabled]:focus,
fieldset[disabled] .btn-danger:focus,
.btn-danger.disabled:active,
.btn-danger[disabled]:active,
fieldset[disabled] .btn-danger:active,
.btn-danger.disabled.active,
.btn-danger[disabled].active,
fieldset[disabled] .btn-danger.active {
  background-color: #d9534f;
  border-color: #d43f3a; }

.btn-success {
  color: #ffffff;
  background-color: #5cb85c;
  border-color: #4cae4c; }

.btn-success:hover,
.btn-success:focus,
.btn-success:active,
.btn-success.active,
.open .dropdown-toggle.btn-success {
  color: #ffffff;
  background-color: #47a447;
  border-color: #398439; }

.btn-success:active,
.btn-success.active,
.open .dropdown-toggle.btn-success {
  background-image: none; }

.btn-success.disabled,
.btn-success[disabled],
fieldset[disabled] .btn-success,
.btn-success.disabled:hover,
.btn-success[disabled]:hover,
fieldset[disabled] .btn-success:hover,
.btn-success.disabled:focus,
.btn-success[disabled]:focus,
fieldset[disabled] .btn-success:focus,
.btn-success.disabled:active,
.btn-success[disabled]:active,
fieldset[disabled] .btn-success:active,
.btn-success.disabled.active,
.btn-success[disabled].active,
fieldset[disabled] .btn-success.active {
  background-color: #5cb85c;
  border-color: #4cae4c; }

.btn-info {
  color: #ffffff;
  background-color: #5bc0de;
  border-color: #46b8da; }

.btn-info:hover,
.btn-info:focus,
.btn-info:active,
.btn-info.active,
.open .dropdown-toggle.btn-info {
  color: #ffffff;
  background-color: #39b3d7;
  border-color: #269abc; }

.btn-info:active,
.btn-info.active,
.open .dropdown-toggle.btn-info {
  background-image: none; }

.btn-info.disabled,
.btn-info[disabled],
fieldset[disabled] .btn-info,
.btn-info.disabled:hover,
.btn-info[disabled]:hover,
fieldset[disabled] .btn-info:hover,
.btn-info.disabled:focus,
.btn-info[disabled]:focus,
fieldset[disabled] .btn-info:focus,
.btn-info.disabled:active,
.btn-info[disabled]:active,
fieldset[disabled] .btn-info:active,
.btn-info.disabled.active,
.btn-info[disabled].active,
fieldset[disabled] .btn-info.active {
  background-color: #5bc0de;
  border-color: #46b8da; }

.btn-link {
  font-weight: normal;
  color: #428bca;
  cursor: pointer;
  border-radius: 0; }

.btn-link,
.btn-link:active,
.btn-link[disabled],
fieldset[disabled] .btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none; }

.btn-link,
.btn-link:hover,
.btn-link:focus,
.btn-link:active {
  border-color: transparent; }

.btn-link:hover,
.btn-link:focus {
  color: #2a6496;
  text-decoration: underline;
  background-color: transparent; }

.btn-link[disabled]:hover,
fieldset[disabled] .btn-link:hover,
.btn-link[disabled]:focus,
fieldset[disabled] .btn-link:focus {
  color: #999999;
  text-decoration: none; }

.btn-lg {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33;
  border-radius: 6px; }

.btn-sm,
.btn-xs {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

.btn-xs {
  padding: 1px 5px; }

.btn-block {
  display: block;
  width: 100%;
  padding-right: 0;
  padding-left: 0; }

.btn-block + .btn-block {
  margin-top: 5px; }

input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%; }

.fade {
  opacity: 0;
  -webkit-transition: opacity 0.15s linear;
  transition: opacity 0.15s linear; }

.fade.in {
  opacity: 1; }

.collapse {
  display: none; }

.collapse.in {
  display: block; }

.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition: height 0.35s ease;
  transition: height 0.35s ease; }

@font-face {
  font-family: 'Glyphicons Halflings';
  src: url(2469ccfe446daa49d5c1446732d1436d.eot);
  src: url(2469ccfe446daa49d5c1446732d1436d.eot?#iefix) format("embedded-opentype"), url(7c4cbe928205c888831ba76548563ca3.woff) format("woff"), url(aa9c7490c2fd52cb96c729753cc4f2d5.ttf) format("truetype"), url(3b31e1de93290779334c84c9b07c6eed.svg#glyphicons-halflingsregular) format("svg"); }

.glyphicon {
  position: relative;
  top: 1px;
  display: inline-block;
  font-family: 'Glyphicons Halflings';
  -webkit-font-smoothing: antialiased;
  font-style: normal;
  font-weight: normal;
  line-height: 1; }

.glyphicon:empty {
  width: 1em; }

.glyphicon-asterisk:before {
  content: "*"; }

.glyphicon-plus:before {
  content: "+"; }

.glyphicon-euro:before {
  content: "\20AC"; }

.glyphicon-minus:before {
  content: "\2212"; }

.glyphicon-cloud:before {
  content: "\2601"; }

.glyphicon-envelope:before {
  content: "\2709"; }

.glyphicon-pencil:before {
  content: "\270F"; }

.glyphicon-glass:before {
  content: "\E001"; }

.glyphicon-music:before {
  content: "\E002"; }

.glyphicon-search:before {
  content: "\E003"; }

.glyphicon-heart:before {
  content: "\E005"; }

.glyphicon-star:before {
  content: "\E006"; }

.glyphicon-star-empty:before {
  content: "\E007"; }

.glyphicon-user:before {
  content: "\E008"; }

.glyphicon-film:before {
  content: "\E009"; }

.glyphicon-th-large:before {
  content: "\E010"; }

.glyphicon-th:before {
  content: "\E011"; }

.glyphicon-th-list:before {
  content: "\E012"; }

.glyphicon-ok:before {
  content: "\E013"; }

.glyphicon-remove:before {
  content: "\E014"; }

.glyphicon-zoom-in:before {
  content: "\E015"; }

.glyphicon-zoom-out:before {
  content: "\E016"; }

.glyphicon-off:before {
  content: "\E017"; }

.glyphicon-signal:before {
  content: "\E018"; }

.glyphicon-cog:before {
  content: "\E019"; }

.glyphicon-trash:before {
  content: "\E020"; }

.glyphicon-home:before {
  content: "\E021"; }

.glyphicon-file:before {
  content: "\E022"; }

.glyphicon-time:before {
  content: "\E023"; }

.glyphicon-road:before {
  content: "\E024"; }

.glyphicon-download-alt:before {
  content: "\E025"; }

.glyphicon-download:before {
  content: "\E026"; }

.glyphicon-upload:before {
  content: "\E027"; }

.glyphicon-inbox:before {
  content: "\E028"; }

.glyphicon-play-circle:before {
  content: "\E029"; }

.glyphicon-repeat:before {
  content: "\E030"; }

.glyphicon-refresh:before {
  content: "\E031"; }

.glyphicon-list-alt:before {
  content: "\E032"; }

.glyphicon-flag:before {
  content: "\E034"; }

.glyphicon-headphones:before {
  content: "\E035"; }

.glyphicon-volume-off:before {
  content: "\E036"; }

.glyphicon-volume-down:before {
  content: "\E037"; }

.glyphicon-volume-up:before {
  content: "\E038"; }

.glyphicon-qrcode:before {
  content: "\E039"; }

.glyphicon-barcode:before {
  content: "\E040"; }

.glyphicon-tag:before {
  content: "\E041"; }

.glyphicon-tags:before {
  content: "\E042"; }

.glyphicon-book:before {
  content: "\E043"; }

.glyphicon-print:before {
  content: "\E045"; }

.glyphicon-font:before {
  content: "\E047"; }

.glyphicon-bold:before {
  content: "\E048"; }

.glyphicon-italic:before {
  content: "\E049"; }

.glyphicon-text-height:before {
  content: "\E050"; }

.glyphicon-text-width:before {
  content: "\E051"; }

.glyphicon-align-left:before {
  content: "\E052"; }

.glyphicon-align-center:before {
  content: "\E053"; }

.glyphicon-align-right:before {
  content: "\E054"; }

.glyphicon-align-justify:before {
  content: "\E055"; }

.glyphicon-list:before {
  content: "\E056"; }

.glyphicon-indent-left:before {
  content: "\E057"; }

.glyphicon-indent-right:before {
  content: "\E058"; }

.glyphicon-facetime-video:before {
  content: "\E059"; }

.glyphicon-picture:before {
  content: "\E060"; }

.glyphicon-map-marker:before {
  content: "\E062"; }

.glyphicon-adjust:before {
  content: "\E063"; }

.glyphicon-tint:before {
  content: "\E064"; }

.glyphicon-edit:before {
  content: "\E065"; }

.glyphicon-share:before {
  content: "\E066"; }

.glyphicon-check:before {
  content: "\E067"; }

.glyphicon-move:before {
  content: "\E068"; }

.glyphicon-step-backward:before {
  content: "\E069"; }

.glyphicon-fast-backward:before {
  content: "\E070"; }

.glyphicon-backward:before {
  content: "\E071"; }

.glyphicon-play:before {
  content: "\E072"; }

.glyphicon-pause:before {
  content: "\E073"; }

.glyphicon-stop:before {
  content: "\E074"; }

.glyphicon-forward:before {
  content: "\E075"; }

.glyphicon-fast-forward:before {
  content: "\E076"; }

.glyphicon-step-forward:before {
  content: "\E077"; }

.glyphicon-eject:before {
  content: "\E078"; }

.glyphicon-chevron-left:before {
  content: "\E079"; }

.glyphicon-chevron-right:before {
  content: "\E080"; }

.glyphicon-plus-sign:before {
  content: "\E081"; }

.glyphicon-minus-sign:before {
  content: "\E082"; }

.glyphicon-remove-sign:before {
  content: "\E083"; }

.glyphicon-ok-sign:before {
  content: "\E084"; }

.glyphicon-question-sign:before {
  content: "\E085"; }

.glyphicon-info-sign:before {
  content: "\E086"; }

.glyphicon-screenshot:before {
  content: "\E087"; }

.glyphicon-remove-circle:before {
  content: "\E088"; }

.glyphicon-ok-circle:before {
  content: "\E089"; }

.glyphicon-ban-circle:before {
  content: "\E090"; }

.glyphicon-arrow-left:before {
  content: "\E091"; }

.glyphicon-arrow-right:before {
  content: "\E092"; }

.glyphicon-arrow-up:before {
  content: "\E093"; }

.glyphicon-arrow-down:before {
  content: "\E094"; }

.glyphicon-share-alt:before {
  content: "\E095"; }

.glyphicon-resize-full:before {
  content: "\E096"; }

.glyphicon-resize-small:before {
  content: "\E097"; }

.glyphicon-exclamation-sign:before {
  content: "\E101"; }

.glyphicon-gift:before {
  content: "\E102"; }

.glyphicon-leaf:before {
  content: "\E103"; }

.glyphicon-eye-open:before {
  content: "\E105"; }

.glyphicon-eye-close:before {
  content: "\E106"; }

.glyphicon-warning-sign:before {
  content: "\E107"; }

.glyphicon-plane:before {
  content: "\E108"; }

.glyphicon-random:before {
  content: "\E110"; }

.glyphicon-comment:before {
  content: "\E111"; }

.glyphicon-magnet:before {
  content: "\E112"; }

.glyphicon-chevron-up:before {
  content: "\E113"; }

.glyphicon-chevron-down:before {
  content: "\E114"; }

.glyphicon-retweet:before {
  content: "\E115"; }

.glyphicon-shopping-cart:before {
  content: "\E116"; }

.glyphicon-folder-close:before {
  content: "\E117"; }

.glyphicon-folder-open:before {
  content: "\E118"; }

.glyphicon-resize-vertical:before {
  content: "\E119"; }

.glyphicon-resize-horizontal:before {
  content: "\E120"; }

.glyphicon-hdd:before {
  content: "\E121"; }

.glyphicon-bullhorn:before {
  content: "\E122"; }

.glyphicon-certificate:before {
  content: "\E124"; }

.glyphicon-thumbs-up:before {
  content: "\E125"; }

.glyphicon-thumbs-down:before {
  content: "\E126"; }

.glyphicon-hand-right:before {
  content: "\E127"; }

.glyphicon-hand-left:before {
  content: "\E128"; }

.glyphicon-hand-up:before {
  content: "\E129"; }

.glyphicon-hand-down:before {
  content: "\E130"; }

.glyphicon-circle-arrow-right:before {
  content: "\E131"; }

.glyphicon-circle-arrow-left:before {
  content: "\E132"; }

.glyphicon-circle-arrow-up:before {
  content: "\E133"; }

.glyphicon-circle-arrow-down:before {
  content: "\E134"; }

.glyphicon-globe:before {
  content: "\E135"; }

.glyphicon-tasks:before {
  content: "\E137"; }

.glyphicon-filter:before {
  content: "\E138"; }

.glyphicon-fullscreen:before {
  content: "\E140"; }

.glyphicon-dashboard:before {
  content: "\E141"; }

.glyphicon-heart-empty:before {
  content: "\E143"; }

.glyphicon-link:before {
  content: "\E144"; }

.glyphicon-phone:before {
  content: "\E145"; }

.glyphicon-usd:before {
  content: "\E148"; }

.glyphicon-gbp:before {
  content: "\E149"; }

.glyphicon-sort:before {
  content: "\E150"; }

.glyphicon-sort-by-alphabet:before {
  content: "\E151"; }

.glyphicon-sort-by-alphabet-alt:before {
  content: "\E152"; }

.glyphicon-sort-by-order:before {
  content: "\E153"; }

.glyphicon-sort-by-order-alt:before {
  content: "\E154"; }

.glyphicon-sort-by-attributes:before {
  content: "\E155"; }

.glyphicon-sort-by-attributes-alt:before {
  content: "\E156"; }

.glyphicon-unchecked:before {
  content: "\E157"; }

.glyphicon-expand:before {
  content: "\E158"; }

.glyphicon-collapse-down:before {
  content: "\E159"; }

.glyphicon-collapse-up:before {
  content: "\E160"; }

.glyphicon-log-in:before {
  content: "\E161"; }

.glyphicon-flash:before {
  content: "\E162"; }

.glyphicon-log-out:before {
  content: "\E163"; }

.glyphicon-new-window:before {
  content: "\E164"; }

.glyphicon-record:before {
  content: "\E165"; }

.glyphicon-save:before {
  content: "\E166"; }

.glyphicon-open:before {
  content: "\E167"; }

.glyphicon-saved:before {
  content: "\E168"; }

.glyphicon-import:before {
  content: "\E169"; }

.glyphicon-export:before {
  content: "\E170"; }

.glyphicon-send:before {
  content: "\E171"; }

.glyphicon-floppy-disk:before {
  content: "\E172"; }

.glyphicon-floppy-saved:before {
  content: "\E173"; }

.glyphicon-floppy-remove:before {
  content: "\E174"; }

.glyphicon-floppy-save:before {
  content: "\E175"; }

.glyphicon-floppy-open:before {
  content: "\E176"; }

.glyphicon-credit-card:before {
  content: "\E177"; }

.glyphicon-transfer:before {
  content: "\E178"; }

.glyphicon-cutlery:before {
  content: "\E179"; }

.glyphicon-header:before {
  content: "\E180"; }

.glyphicon-compressed:before {
  content: "\E181"; }

.glyphicon-earphone:before {
  content: "\E182"; }

.glyphicon-phone-alt:before {
  content: "\E183"; }

.glyphicon-tower:before {
  content: "\E184"; }

.glyphicon-stats:before {
  content: "\E185"; }

.glyphicon-sd-video:before {
  content: "\E186"; }

.glyphicon-hd-video:before {
  content: "\E187"; }

.glyphicon-subtitles:before {
  content: "\E188"; }

.glyphicon-sound-stereo:before {
  content: "\E189"; }

.glyphicon-sound-dolby:before {
  content: "\E190"; }

.glyphicon-sound-5-1:before {
  content: "\E191"; }

.glyphicon-sound-6-1:before {
  content: "\E192"; }

.glyphicon-sound-7-1:before {
  content: "\E193"; }

.glyphicon-copyright-mark:before {
  content: "\E194"; }

.glyphicon-registration-mark:before {
  content: "\E195"; }

.glyphicon-cloud-download:before {
  content: "\E197"; }

.glyphicon-cloud-upload:before {
  content: "\E198"; }

.glyphicon-tree-conifer:before {
  content: "\E199"; }

.glyphicon-tree-deciduous:before {
  content: "\E200"; }

.glyphicon-briefcase:before {
  content: "\1F4BC"; }

.glyphicon-calendar:before {
  content: "\1F4C5"; }

.glyphicon-pushpin:before {
  content: "\1F4CC"; }

.glyphicon-paperclip:before {
  content: "\1F4CE"; }

.glyphicon-camera:before {
  content: "\1F4F7"; }

.glyphicon-lock:before {
  content: "\1F512"; }

.glyphicon-bell:before {
  content: "\1F514"; }

.glyphicon-bookmark:before {
  content: "\1F516"; }

.glyphicon-fire:before {
  content: "\1F525"; }

.glyphicon-wrench:before {
  content: "\1F527"; }

.caret {
  display: inline-block;
  width: 0;
  height: 0;
  margin-left: 2px;
  vertical-align: middle;
  border-top: 4px solid #000000;
  border-right: 4px solid transparent;
  border-bottom: 0 dotted;
  border-left: 4px solid transparent;
  content: ""; }

.dropdown {
  position: relative; }

.dropdown-toggle:focus {
  outline: 0; }

.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  font-size: 14px;
  list-style: none;
  background-color: #ffffff;
  border: 1px solid #cccccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 4px;
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  background-clip: padding-box; }

.dropdown-menu.pull-right {
  right: 0;
  left: auto; }

.dropdown-menu .divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5; }

.dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.428571429;
  color: #333333;
  white-space: nowrap; }

.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus {
  color: #262626;
  text-decoration: none;
  background-color: #f5f5f5; }

.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  color: #ffffff;
  text-decoration: none;
  background-color: #428bca;
  outline: 0; }

.dropdown-menu > .disabled > a,
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  color: #999999; }

.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  text-decoration: none;
  cursor: not-allowed;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }

.open > .dropdown-menu {
  display: block; }

.open > a {
  outline: 0; }

.dropdown-header {
  display: block;
  padding: 3px 20px;
  font-size: 12px;
  line-height: 1.428571429;
  color: #999999; }

.dropdown-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 990; }

.pull-right > .dropdown-menu {
  right: 0;
  left: auto; }

.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
  border-top: 0 dotted;
  border-bottom: 4px solid #000000;
  content: ""; }

.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 1px; }

@media (min-width: 768px) {
  .navbar-right .dropdown-menu {
    right: 0;
    left: auto; } }

.btn-default .caret {
  border-top-color: #333333; }

.btn-primary .caret,
.btn-success .caret,
.btn-warning .caret,
.btn-danger .caret,
.btn-info .caret {
  border-top-color: #fff; }

.dropup .btn-default .caret {
  border-bottom-color: #333333; }

.dropup .btn-primary .caret,
.dropup .btn-success .caret,
.dropup .btn-warning .caret,
.dropup .btn-danger .caret,
.dropup .btn-info .caret {
  border-bottom-color: #fff; }

.btn-group,
.btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle; }

.btn-group > .btn,
.btn-group-vertical > .btn {
  position: relative;
  float: left; }

.btn-group > .btn:hover,
.btn-group-vertical > .btn:hover,
.btn-group > .btn:focus,
.btn-group-vertical > .btn:focus,
.btn-group > .btn:active,
.btn-group-vertical > .btn:active,
.btn-group > .btn.active,
.btn-group-vertical > .btn.active {
  z-index: 2; }

.btn-group > .btn:focus,
.btn-group-vertical > .btn:focus {
  outline: none; }

.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
  margin-left: -1px; }

.btn-toolbar:before,
.btn-toolbar:after {
  display: table;
  content: " "; }

.btn-toolbar:after {
  clear: both; }

.btn-toolbar:before,
.btn-toolbar:after {
  display: table;
  content: " "; }

.btn-toolbar:after {
  clear: both; }

.btn-toolbar .btn-group {
  float: left; }

.btn-toolbar > .btn + .btn,
.btn-toolbar > .btn-group + .btn,
.btn-toolbar > .btn + .btn-group,
.btn-toolbar > .btn-group + .btn-group {
  margin-left: 5px; }

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0; }

.btn-group > .btn:first-child {
  margin-left: 0; }

.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0; }

.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

.btn-group > .btn-group {
  float: left; }

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0; }

.btn-group > .btn-group:first-child > .btn:last-child,
.btn-group > .btn-group:first-child > .dropdown-toggle {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0; }

.btn-group > .btn-group:last-child > .btn:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0; }

.btn-group-xs > .btn {
  padding: 5px 10px;
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

.btn-group-sm > .btn {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

.btn-group-lg > .btn {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33;
  border-radius: 6px; }

.btn-group > .btn + .dropdown-toggle {
  padding-right: 8px;
  padding-left: 8px; }

.btn-group > .btn-lg + .dropdown-toggle {
  padding-right: 12px;
  padding-left: 12px; }

.btn-group.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }

.btn .caret {
  margin-left: 0; }

.btn-lg .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0; }

.dropup .btn-lg .caret {
  border-width: 0 5px 5px; }

.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%; }

.btn-group-vertical > .btn-group:before,
.btn-group-vertical > .btn-group:after {
  display: table;
  content: " "; }

.btn-group-vertical > .btn-group:after {
  clear: both; }

.btn-group-vertical > .btn-group:before,
.btn-group-vertical > .btn-group:after {
  display: table;
  content: " "; }

.btn-group-vertical > .btn-group:after {
  clear: both; }

.btn-group-vertical > .btn-group > .btn {
  float: none; }

.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
  margin-top: -1px;
  margin-left: 0; }

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0; }

.btn-group-vertical > .btn:first-child:not(:last-child) {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

.btn-group-vertical > .btn:last-child:not(:first-child) {
  border-top-right-radius: 0;
  border-bottom-left-radius: 4px;
  border-top-left-radius: 0; }

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0; }

.btn-group-vertical > .btn-group:first-child > .btn:last-child,
.btn-group-vertical > .btn-group:first-child > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

.btn-group-vertical > .btn-group:last-child > .btn:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

.btn-group-justified {
  display: table;
  width: 100%;
  border-collapse: separate;
  table-layout: fixed; }

.btn-group-justified .btn {
  display: table-cell;
  float: none;
  width: 1%; }

[data-toggle="buttons"] > .btn > input[type="radio"],
[data-toggle="buttons"] > .btn > input[type="checkbox"] {
  display: none; }

.input-group {
  position: relative;
  display: table;
  border-collapse: separate; }

.input-group.col {
  float: none;
  padding-right: 0;
  padding-left: 0; }

.input-group .form-control {
  width: 100%;
  margin-bottom: 0; }

.input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
  height: 45px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33;
  border-radius: 6px; }

select.input-group-lg > .form-control,
select.input-group-lg > .input-group-addon,
select.input-group-lg > .input-group-btn > .btn {
  height: 45px;
  line-height: 45px; }

textarea.input-group-lg > .form-control,
textarea.input-group-lg > .input-group-addon,
textarea.input-group-lg > .input-group-btn > .btn {
  height: auto; }

.input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

select.input-group-sm > .form-control,
select.input-group-sm > .input-group-addon,
select.input-group-sm > .input-group-btn > .btn {
  height: 30px;
  line-height: 30px; }

textarea.input-group-sm > .form-control,
textarea.input-group-sm > .input-group-addon,
textarea.input-group-sm > .input-group-btn > .btn {
  height: auto; }

.input-group-addon,
.input-group-btn,
.input-group .form-control {
  display: table-cell; }

.input-group-addon:not(:first-child):not(:last-child),
.input-group-btn:not(:first-child):not(:last-child),
.input-group .form-control:not(:first-child):not(:last-child) {
  border-radius: 0; }

.input-group-addon,
.input-group-btn {
  width: 1%;
  white-space: nowrap;
  vertical-align: middle; }

.input-group-addon {
  padding: 6px 12px;
  font-size: 14px;
  font-weight: normal;
  line-height: 1;
  color: #555555;
  text-align: center;
  background-color: #eeeeee;
  border: 1px solid #cccccc;
  border-radius: 4px; }

.input-group-addon.input-sm {
  padding: 5px 10px;
  font-size: 12px;
  border-radius: 3px; }

.input-group-addon.input-lg {
  padding: 10px 16px;
  font-size: 18px;
  border-radius: 6px; }

.input-group-addon input[type="radio"],
.input-group-addon input[type="checkbox"] {
  margin-top: 0; }

.input-group .form-control:first-child,
.input-group-addon:first-child,
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .dropdown-toggle,
.input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0; }

.input-group-addon:first-child {
  border-right: 0; }

.input-group .form-control:last-child,
.input-group-addon:last-child,
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .dropdown-toggle,
.input-group-btn:first-child > .btn:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

.input-group-addon:last-child {
  border-left: 0; }

.input-group-btn {
  position: relative;
  white-space: nowrap; }

.input-group-btn:first-child > .btn {
  margin-right: -1px; }

.input-group-btn:last-child > .btn {
  margin-left: -1px; }

.input-group-btn > .btn {
  position: relative; }

.input-group-btn > .btn + .btn {
  margin-left: -4px; }

.input-group-btn > .btn:hover,
.input-group-btn > .btn:active {
  z-index: 2; }

.nav {
  padding-left: 0;
  margin-bottom: 0;
  list-style: none; }

.nav:before,
.nav:after {
  display: table;
  content: " "; }

.nav:after {
  clear: both; }

.nav:before,
.nav:after {
  display: table;
  content: " "; }

.nav:after {
  clear: both; }

.nav > li {
  position: relative;
  display: block; }

.nav > li > a {
  position: relative;
  display: block;
  padding: 10px 15px; }

.nav > li > a:hover,
.nav > li > a:focus {
  text-decoration: none;
  background-color: #eeeeee; }

.nav > li.disabled > a {
  color: #999999; }

.nav > li.disabled > a:hover,
.nav > li.disabled > a:focus {
  color: #999999;
  text-decoration: none;
  cursor: not-allowed;
  background-color: transparent; }

.nav .open > a,
.nav .open > a:hover,
.nav .open > a:focus {
  background-color: #eeeeee;
  border-color: #428bca; }

.nav .nav-divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5; }

.nav > li > a > img {
  max-width: none; }

.nav-tabs {
  border-bottom: 1px solid #dddddd; }

.nav-tabs > li {
  float: left;
  margin-bottom: -1px; }

.nav-tabs > li > a {
  margin-right: 2px;
  line-height: 1.428571429;
  border: 1px solid transparent;
  border-radius: 4px 4px 0 0; }

.nav-tabs > li > a:hover {
  border-color: #eeeeee #eeeeee #dddddd; }

.nav-tabs > li.active > a,
.nav-tabs > li.active > a:hover,
.nav-tabs > li.active > a:focus {
  color: #555555;
  cursor: default;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-bottom-color: transparent; }

.nav-tabs.nav-justified {
  width: 100%;
  border-bottom: 0; }

.nav-tabs.nav-justified > li {
  float: none; }

.nav-tabs.nav-justified > li > a {
  margin-bottom: 5px;
  text-align: center; }

@media (min-width: 768px) {
  .nav-tabs.nav-justified > li {
    display: table-cell;
    width: 1%; }
  .nav-tabs.nav-justified > li > a {
    margin-bottom: 0; } }

.nav-tabs.nav-justified > li > a {
  margin-right: 0;
  border-radius: 4px; }

.nav-tabs.nav-justified > .active > a,
.nav-tabs.nav-justified > .active > a:hover,
.nav-tabs.nav-justified > .active > a:focus {
  border: 1px solid #dddddd; }

@media (min-width: 768px) {
  .nav-tabs.nav-justified > li > a {
    border-bottom: 1px solid #dddddd;
    border-radius: 4px 4px 0 0; }
  .nav-tabs.nav-justified > .active > a,
  .nav-tabs.nav-justified > .active > a:hover,
  .nav-tabs.nav-justified > .active > a:focus {
    border-bottom-color: #ffffff; } }

.nav-pills > li {
  float: left; }

.nav-pills > li > a {
  border-radius: 5px; }

.nav-pills > li + li {
  margin-left: 2px; }

.nav-pills > li.active > a,
.nav-pills > li.active > a:hover,
.nav-pills > li.active > a:focus {
  color: #ffffff;
  background-color: #428bca; }

.nav-stacked > li {
  float: none; }

.nav-stacked > li + li {
  margin-top: 2px;
  margin-left: 0; }

.nav-justified {
  width: 100%; }

.nav-justified > li {
  float: none; }

.nav-justified > li > a {
  margin-bottom: 5px;
  text-align: center; }

@media (min-width: 768px) {
  .nav-justified > li {
    display: table-cell;
    width: 1%; }
  .nav-justified > li > a {
    margin-bottom: 0; } }

.nav-tabs-justified {
  border-bottom: 0; }

.nav-tabs-justified > li > a {
  margin-right: 0;
  border-radius: 4px; }

.nav-tabs-justified > .active > a,
.nav-tabs-justified > .active > a:hover,
.nav-tabs-justified > .active > a:focus {
  border: 1px solid #dddddd; }

@media (min-width: 768px) {
  .nav-tabs-justified > li > a {
    border-bottom: 1px solid #dddddd;
    border-radius: 4px 4px 0 0; }
  .nav-tabs-justified > .active > a,
  .nav-tabs-justified > .active > a:hover,
  .nav-tabs-justified > .active > a:focus {
    border-bottom-color: #ffffff; } }

.tabbable:before,
.tabbable:after {
  display: table;
  content: " "; }

.tabbable:after {
  clear: both; }

.tabbable:before,
.tabbable:after {
  display: table;
  content: " "; }

.tabbable:after {
  clear: both; }

.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none; }

.tab-content > .active,
.pill-content > .active {
  display: block; }

.nav .caret {
  border-top-color: #428bca;
  border-bottom-color: #428bca; }

.nav a:hover .caret {
  border-top-color: #2a6496;
  border-bottom-color: #2a6496; }

.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

.navbar {
  position: relative;
  z-index: 1000;
  min-height: 50px;
  margin-bottom: 20px;
  border: 1px solid transparent; }

.navbar:before,
.navbar:after {
  display: table;
  content: " "; }

.navbar:after {
  clear: both; }

.navbar:before,
.navbar:after {
  display: table;
  content: " "; }

.navbar:after {
  clear: both; }

@media (min-width: 768px) {
  .navbar {
    border-radius: 4px; } }

.navbar-header:before,
.navbar-header:after {
  display: table;
  content: " "; }

.navbar-header:after {
  clear: both; }

.navbar-header:before,
.navbar-header:after {
  display: table;
  content: " "; }

.navbar-header:after {
  clear: both; }

@media (min-width: 768px) {
  .navbar-header {
    float: left; } }

.navbar-collapse {
  max-height: 340px;
  padding-right: 15px;
  padding-left: 15px;
  overflow-x: visible;
  border-top: 1px solid transparent;
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
  -webkit-overflow-scrolling: touch; }

.navbar-collapse:before,
.navbar-collapse:after {
  display: table;
  content: " "; }

.navbar-collapse:after {
  clear: both; }

.navbar-collapse:before,
.navbar-collapse:after {
  display: table;
  content: " "; }

.navbar-collapse:after {
  clear: both; }

.navbar-collapse.in {
  overflow-y: auto; }

@media (min-width: 768px) {
  .navbar-collapse {
    width: auto;
    border-top: 0;
    box-shadow: none; }
  .navbar-collapse.collapse {
    display: block !important;
    height: auto !important;
    padding-bottom: 0;
    overflow: visible !important; }
  .navbar-collapse.in {
    overflow-y: visible; }
  .navbar-collapse .navbar-nav.navbar-left:first-child {
    margin-left: -15px; }
  .navbar-collapse .navbar-nav.navbar-right:last-child {
    margin-right: -15px; }
  .navbar-collapse .navbar-text:last-child {
    margin-right: 0; } }

.container > .navbar-header,
.container > .navbar-collapse {
  margin-right: -15px;
  margin-left: -15px; }

@media (min-width: 768px) {
  .container > .navbar-header,
  .container > .navbar-collapse {
    margin-right: 0;
    margin-left: 0; } }

.navbar-static-top {
  border-width: 0 0 1px; }

@media (min-width: 768px) {
  .navbar-static-top {
    border-radius: 0; } }

.navbar-fixed-top,
.navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  border-width: 0 0 1px; }

@media (min-width: 768px) {
  .navbar-fixed-top,
  .navbar-fixed-bottom {
    border-radius: 0; } }

.navbar-fixed-top {
  top: 0;
  z-index: 1030; }

.navbar-fixed-bottom {
  bottom: 0;
  margin-bottom: 0; }

.navbar-brand {
  float: left;
  padding: 15px 15px;
  font-size: 18px;
  line-height: 20px; }

.navbar-brand:hover,
.navbar-brand:focus {
  text-decoration: none; }

@media (min-width: 768px) {
  .navbar > .container .navbar-brand {
    margin-left: -15px; } }

.navbar-toggle {
  position: relative;
  float: right;
  padding: 9px 10px;
  margin-top: 8px;
  margin-right: 15px;
  margin-bottom: 8px;
  background-color: transparent;
  border: 1px solid transparent;
  border-radius: 4px; }

.navbar-toggle .icon-bar {
  display: block;
  width: 22px;
  height: 2px;
  border-radius: 1px; }

.navbar-toggle .icon-bar + .icon-bar {
  margin-top: 4px; }

@media (min-width: 768px) {
  .navbar-toggle {
    display: none; } }

.navbar-nav {
  margin: 7.5px -15px; }

.navbar-nav > li > a {
  padding-top: 10px;
  padding-bottom: 10px;
  line-height: 20px; }

@media (max-width: 767px) {
  .navbar-nav .open .dropdown-menu {
    position: static;
    float: none;
    width: auto;
    margin-top: 0;
    background-color: transparent;
    border: 0;
    box-shadow: none; }
  .navbar-nav .open .dropdown-menu > li > a,
  .navbar-nav .open .dropdown-menu .dropdown-header {
    padding: 5px 15px 5px 25px; }
  .navbar-nav .open .dropdown-menu > li > a {
    line-height: 20px; }
  .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-nav .open .dropdown-menu > li > a:focus {
    background-image: none; } }

@media (min-width: 768px) {
  .navbar-nav {
    float: left;
    margin: 0; }
  .navbar-nav > li {
    float: left; }
  .navbar-nav > li > a {
    padding-top: 15px;
    padding-bottom: 15px; } }

@media (min-width: 768px) {
  .navbar-left {
    float: left !important; }
  .navbar-right {
    float: right !important; } }

.navbar-form {
  padding: 10px 15px;
  margin-top: 8px;
  margin-right: -15px;
  margin-bottom: 8px;
  margin-left: -15px;
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1); }

@media (min-width: 768px) {
  .navbar-form .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle; }
  .navbar-form .form-control {
    display: inline-block; }
  .navbar-form .radio,
  .navbar-form .checkbox {
    display: inline-block;
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0; }
  .navbar-form .radio input[type="radio"],
  .navbar-form .checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0; } }

@media (max-width: 767px) {
  .navbar-form .form-group {
    margin-bottom: 5px; } }

@media (min-width: 768px) {
  .navbar-form {
    width: auto;
    padding-top: 0;
    padding-bottom: 0;
    margin-right: 0;
    margin-left: 0;
    border: 0;
    -webkit-box-shadow: none;
    box-shadow: none; } }

.navbar-nav > li > .dropdown-menu {
  margin-top: 0;
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

.navbar-nav.pull-right > li > .dropdown-menu,
.navbar-nav > li > .dropdown-menu.pull-right {
  right: 0;
  left: auto; }

.navbar-btn {
  margin-top: 8px;
  margin-bottom: 8px; }

.navbar-text {
  float: left;
  margin-top: 15px;
  margin-bottom: 15px; }

@media (min-width: 768px) {
  .navbar-text {
    margin-right: 15px;
    margin-left: 15px; } }

.navbar-default {
  background-color: #f8f8f8;
  border-color: #e7e7e7; }

.navbar-default .navbar-brand {
  color: #777777; }

.navbar-default .navbar-brand:hover,
.navbar-default .navbar-brand:focus {
  color: #5e5e5e;
  background-color: transparent; }

.navbar-default .navbar-text {
  color: #777777; }

.navbar-default .navbar-nav > li > a {
  color: #777777; }

.navbar-default .navbar-nav > li > a:hover,
.navbar-default .navbar-nav > li > a:focus {
  color: #333333;
  background-color: transparent; }

.navbar-default .navbar-nav > .active > a,
.navbar-default .navbar-nav > .active > a:hover,
.navbar-default .navbar-nav > .active > a:focus {
  color: #555555;
  background-color: #e7e7e7; }

.navbar-default .navbar-nav > .disabled > a,
.navbar-default .navbar-nav > .disabled > a:hover,
.navbar-default .navbar-nav > .disabled > a:focus {
  color: #cccccc;
  background-color: transparent; }

.navbar-default .navbar-toggle {
  border-color: #dddddd; }

.navbar-default .navbar-toggle:hover,
.navbar-default .navbar-toggle:focus {
  background-color: #dddddd; }

.navbar-default .navbar-toggle .icon-bar {
  background-color: #cccccc; }

.navbar-default .navbar-collapse,
.navbar-default .navbar-form {
  border-color: #e6e6e6; }

.navbar-default .navbar-nav > .dropdown > a:hover .caret,
.navbar-default .navbar-nav > .dropdown > a:focus .caret {
  border-top-color: #333333;
  border-bottom-color: #333333; }

.navbar-default .navbar-nav > .open > a,
.navbar-default .navbar-nav > .open > a:hover,
.navbar-default .navbar-nav > .open > a:focus {
  color: #555555;
  background-color: #e7e7e7; }

.navbar-default .navbar-nav > .open > a .caret,
.navbar-default .navbar-nav > .open > a:hover .caret,
.navbar-default .navbar-nav > .open > a:focus .caret {
  border-top-color: #555555;
  border-bottom-color: #555555; }

.navbar-default .navbar-nav > .dropdown > a .caret {
  border-top-color: #777777;
  border-bottom-color: #777777; }

@media (max-width: 767px) {
  .navbar-default .navbar-nav .open .dropdown-menu > li > a {
    color: #777777; }
  .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
    color: #333333;
    background-color: transparent; }
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a,
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #555555;
    background-color: #e7e7e7; }
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a,
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
    color: #cccccc;
    background-color: transparent; } }

.navbar-default .navbar-link {
  color: #777777; }

.navbar-default .navbar-link:hover {
  color: #333333; }

.navbar-inverse {
  background-color: #222222;
  border-color: #080808; }

.navbar-inverse .navbar-brand {
  color: #999999; }

.navbar-inverse .navbar-brand:hover,
.navbar-inverse .navbar-brand:focus {
  color: #ffffff;
  background-color: transparent; }

.navbar-inverse .navbar-text {
  color: #999999; }

.navbar-inverse .navbar-nav > li > a {
  color: #999999; }

.navbar-inverse .navbar-nav > li > a:hover,
.navbar-inverse .navbar-nav > li > a:focus {
  color: #ffffff;
  background-color: transparent; }

.navbar-inverse .navbar-nav > .active > a,
.navbar-inverse .navbar-nav > .active > a:hover,
.navbar-inverse .navbar-nav > .active > a:focus {
  color: #ffffff;
  background-color: #080808; }

.navbar-inverse .navbar-nav > .disabled > a,
.navbar-inverse .navbar-nav > .disabled > a:hover,
.navbar-inverse .navbar-nav > .disabled > a:focus {
  color: #444444;
  background-color: transparent; }

.navbar-inverse .navbar-toggle {
  border-color: #333333; }

.navbar-inverse .navbar-toggle:hover,
.navbar-inverse .navbar-toggle:focus {
  background-color: #333333; }

.navbar-inverse .navbar-toggle .icon-bar {
  background-color: #ffffff; }

.navbar-inverse .navbar-collapse,
.navbar-inverse .navbar-form {
  border-color: #101010; }

.navbar-inverse .navbar-nav > .open > a,
.navbar-inverse .navbar-nav > .open > a:hover,
.navbar-inverse .navbar-nav > .open > a:focus {
  color: #ffffff;
  background-color: #080808; }

.navbar-inverse .navbar-nav > .dropdown > a:hover .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff; }

.navbar-inverse .navbar-nav > .dropdown > a .caret {
  border-top-color: #999999;
  border-bottom-color: #999999; }

.navbar-inverse .navbar-nav > .open > a .caret,
.navbar-inverse .navbar-nav > .open > a:hover .caret,
.navbar-inverse .navbar-nav > .open > a:focus .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff; }

@media (max-width: 767px) {
  .navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
    border-color: #080808; }
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
    color: #999999; }
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
    color: #ffffff;
    background-color: transparent; }
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #ffffff;
    background-color: #080808; }
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
    color: #444444;
    background-color: transparent; } }

.navbar-inverse .navbar-link {
  color: #999999; }

.navbar-inverse .navbar-link:hover {
  color: #ffffff; }

.breadcrumb {
  padding: 8px 15px;
  margin-bottom: 20px;
  list-style: none;
  background-color: #f5f5f5;
  border-radius: 4px; }

.breadcrumb > li {
  display: inline-block; }

.breadcrumb > li + li:before {
  padding: 0 5px;
  color: #cccccc;
  content: "/\A0"; }

.breadcrumb > .active {
  color: #999999; }

.pagination {
  display: inline-block;
  padding-left: 0;
  margin: 20px 0;
  border-radius: 4px; }

.pagination > li {
  display: inline; }

.pagination > li > a,
.pagination > li > span {
  position: relative;
  float: left;
  padding: 6px 12px;
  margin-left: -1px;
  line-height: 1.428571429;
  text-decoration: none;
  background-color: #ffffff;
  border: 1px solid #dddddd; }

.pagination > li:first-child > a,
.pagination > li:first-child > span {
  margin-left: 0;
  border-bottom-left-radius: 4px;
  border-top-left-radius: 4px; }

.pagination > li:last-child > a,
.pagination > li:last-child > span {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px; }

.pagination > li > a:hover,
.pagination > li > span:hover,
.pagination > li > a:focus,
.pagination > li > span:focus {
  background-color: #eeeeee; }

.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
  z-index: 2;
  color: #ffffff;
  cursor: default;
  background-color: #428bca;
  border-color: #428bca; }

.pagination > .disabled > span,
.pagination > .disabled > span:hover,
.pagination > .disabled > span:focus,
.pagination > .disabled > a,
.pagination > .disabled > a:hover,
.pagination > .disabled > a:focus {
  color: #999999;
  cursor: not-allowed;
  background-color: #ffffff;
  border-color: #dddddd; }

.pagination-lg > li > a,
.pagination-lg > li > span {
  padding: 10px 16px;
  font-size: 18px; }

.pagination-lg > li:first-child > a,
.pagination-lg > li:first-child > span {
  border-bottom-left-radius: 6px;
  border-top-left-radius: 6px; }

.pagination-lg > li:last-child > a,
.pagination-lg > li:last-child > span {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px; }

.pagination-sm > li > a,
.pagination-sm > li > span {
  padding: 5px 10px;
  font-size: 12px; }

.pagination-sm > li:first-child > a,
.pagination-sm > li:first-child > span {
  border-bottom-left-radius: 3px;
  border-top-left-radius: 3px; }

.pagination-sm > li:last-child > a,
.pagination-sm > li:last-child > span {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px; }

.pager {
  padding-left: 0;
  margin: 20px 0;
  text-align: center;
  list-style: none; }

.pager:before,
.pager:after {
  display: table;
  content: " "; }

.pager:after {
  clear: both; }

.pager:before,
.pager:after {
  display: table;
  content: " "; }

.pager:after {
  clear: both; }

.pager li {
  display: inline; }

.pager li > a,
.pager li > span {
  display: inline-block;
  padding: 5px 14px;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-radius: 15px; }

.pager li > a:hover,
.pager li > a:focus {
  text-decoration: none;
  background-color: #eeeeee; }

.pager .next > a,
.pager .next > span {
  float: right; }

.pager .previous > a,
.pager .previous > span {
  float: left; }

.pager .disabled > a,
.pager .disabled > a:hover,
.pager .disabled > a:focus,
.pager .disabled > span {
  color: #999999;
  cursor: not-allowed;
  background-color: #ffffff; }

.label {
  display: inline;
  padding: .2em .6em .3em;
  font-size: 75%;
  font-weight: bold;
  line-height: 1;
  color: #ffffff;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: .25em; }

.label[href]:hover,
.label[href]:focus {
  color: #ffffff;
  text-decoration: none;
  cursor: pointer; }

.label:empty {
  display: none; }

.label-default {
  background-color: #999999; }

.label-default[href]:hover,
.label-default[href]:focus {
  background-color: #808080; }

.label-primary {
  background-color: #428bca; }

.label-primary[href]:hover,
.label-primary[href]:focus {
  background-color: #3071a9; }

.label-success {
  background-color: #5cb85c; }

.label-success[href]:hover,
.label-success[href]:focus {
  background-color: #449d44; }

.label-info {
  background-color: #5bc0de; }

.label-info[href]:hover,
.label-info[href]:focus {
  background-color: #31b0d5; }

.label-warning {
  background-color: #f0ad4e; }

.label-warning[href]:hover,
.label-warning[href]:focus {
  background-color: #ec971f; }

.label-danger {
  background-color: #d9534f; }

.label-danger[href]:hover,
.label-danger[href]:focus {
  background-color: #c9302c; }

.badge {
  display: inline-block;
  min-width: 10px;
  padding: 3px 7px;
  font-size: 12px;
  font-weight: bold;
  line-height: 1;
  color: #ffffff;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  background-color: #999999;
  border-radius: 10px; }

.badge:empty {
  display: none; }

a.badge:hover,
a.badge:focus {
  color: #ffffff;
  text-decoration: none;
  cursor: pointer; }

.btn .badge {
  position: relative;
  top: -1px; }

a.list-group-item.active > .badge,
.nav-pills > .active > a > .badge {
  color: #428bca;
  background-color: #ffffff; }

.nav-pills > li > a > .badge {
  margin-left: 3px; }

.jumbotron {
  padding: 30px;
  margin-bottom: 30px;
  font-size: 21px;
  font-weight: 200;
  line-height: 2.1428571435;
  color: inherit;
  background-color: #eeeeee; }

.jumbotron h1 {
  line-height: 1;
  color: inherit; }

.jumbotron p {
  line-height: 1.4; }

.container .jumbotron {
  border-radius: 6px; }

@media screen and (min-width: 768px) {
  .jumbotron {
    padding-top: 48px;
    padding-bottom: 48px; }
  .container .jumbotron {
    padding-right: 60px;
    padding-left: 60px; }
  .jumbotron h1 {
    font-size: 63px; } }

.thumbnail {
  display: inline-block;
  display: block;
  height: auto;
  max-width: 100%;
  padding: 4px;
  margin-bottom: 20px;
  line-height: 1.428571429;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-radius: 4px;
  -webkit-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out; }

.thumbnail > img {
  display: block;
  height: auto;
  max-width: 100%; }

a.thumbnail:hover,
a.thumbnail:focus {
  border-color: #428bca; }

.thumbnail > img {
  margin-right: auto;
  margin-left: auto; }

.thumbnail .caption {
  padding: 9px;
  color: #333333; }

.alert {
  padding: 15px;
  margin-bottom: 20px;
  border: 1px solid transparent;
  border-radius: 4px; }

.alert h4 {
  margin-top: 0;
  color: inherit; }

.alert .alert-link {
  font-weight: bold; }

.alert > p,
.alert > ul {
  margin-bottom: 0; }

.alert > p + p {
  margin-top: 5px; }

.alert-dismissable {
  padding-right: 35px; }

.alert-dismissable .close {
  position: relative;
  top: -2px;
  right: -21px;
  color: inherit; }

.alert-success {
  color: #468847;
  background-color: #dff0d8;
  border-color: #d6e9c6; }

.alert-success hr {
  border-top-color: #c9e2b3; }

.alert-success .alert-link {
  color: #356635; }

.alert-info {
  color: #3a87ad;
  background-color: #d9edf7;
  border-color: #bce8f1; }

.alert-info hr {
  border-top-color: #a6e1ec; }

.alert-info .alert-link {
  color: #2d6987; }

.alert-warning {
  color: #c09853;
  background-color: #fcf8e3;
  border-color: #faebcc; }

.alert-warning hr {
  border-top-color: #f7e1b5; }

.alert-warning .alert-link {
  color: #a47e3c; }

.alert-danger {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #ebccd1; }

.alert-danger hr {
  border-top-color: #e4b9c0; }

.alert-danger .alert-link {
  color: #953b39; }

@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

@-moz-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

@-o-keyframes progress-bar-stripes {
  from {
    background-position: 0 0; }
  to {
    background-position: 40px 0; } }

@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

.progress {
  height: 20px;
  margin-bottom: 20px;
  overflow: hidden;
  background-color: #f5f5f5;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1); }

.progress-bar {
  float: left;
  width: 0;
  height: 100%;
  font-size: 12px;
  line-height: 20px;
  color: #ffffff;
  text-align: center;
  background-color: #428bca;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-transition: width 0.6s ease;
  transition: width 0.6s ease; }

.progress-striped .progress-bar {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px; }

.progress.active .progress-bar {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -moz-animation: progress-bar-stripes 2s linear infinite;
  -ms-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite; }

.progress-bar-success {
  background-color: #5cb85c; }

.progress-striped .progress-bar-success {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-info {
  background-color: #5bc0de; }

.progress-striped .progress-bar-info {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-warning {
  background-color: #f0ad4e; }

.progress-striped .progress-bar-warning {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-danger {
  background-color: #d9534f; }

.progress-striped .progress-bar-danger {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.media,
.media-body {
  overflow: hidden;
  zoom: 1; }

.media,
.media .media {
  margin-top: 15px; }

.media:first-child {
  margin-top: 0; }

.media-object {
  display: block; }

.media-heading {
  margin: 0 0 5px; }

.media > .pull-left {
  margin-right: 10px; }

.media > .pull-right {
  margin-left: 10px; }

.media-list {
  padding-left: 0;
  list-style: none; }

.list-group {
  padding-left: 0;
  margin-bottom: 20px; }

.list-group-item {
  position: relative;
  display: block;
  padding: 10px 15px;
  margin-bottom: -1px;
  background-color: #ffffff;
  border: 1px solid #dddddd; }

.list-group-item:first-child {
  border-top-right-radius: 4px;
  border-top-left-radius: 4px; }

.list-group-item:last-child {
  margin-bottom: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px; }

.list-group-item > .badge {
  float: right; }

.list-group-item > .badge + .badge {
  margin-right: 5px; }

a.list-group-item {
  color: #555555; }

a.list-group-item .list-group-item-heading {
  color: #333333; }

a.list-group-item:hover,
a.list-group-item:focus {
  text-decoration: none;
  background-color: #f5f5f5; }

.list-group-item.active,
.list-group-item.active:hover,
.list-group-item.active:focus {
  z-index: 2;
  color: #ffffff;
  background-color: #428bca;
  border-color: #428bca; }

.list-group-item.active .list-group-item-heading,
.list-group-item.active:hover .list-group-item-heading,
.list-group-item.active:focus .list-group-item-heading {
  color: inherit; }

.list-group-item.active .list-group-item-text,
.list-group-item.active:hover .list-group-item-text,
.list-group-item.active:focus .list-group-item-text {
  color: #e1edf7; }

.list-group-item-heading {
  margin-top: 0;
  margin-bottom: 5px; }

.list-group-item-text {
  margin-bottom: 0;
  line-height: 1.3; }

.panel {
  margin-bottom: 20px;
  background-color: #ffffff;
  border: 1px solid transparent;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05); }

.panel-body {
  padding: 15px; }

.panel-body:before,
.panel-body:after {
  display: table;
  content: " "; }

.panel-body:after {
  clear: both; }

.panel-body:before,
.panel-body:after {
  display: table;
  content: " "; }

.panel-body:after {
  clear: both; }

.panel > .list-group {
  margin-bottom: 0; }

.panel > .list-group .list-group-item {
  border-width: 1px 0; }

.panel > .list-group .list-group-item:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

.panel > .list-group .list-group-item:last-child {
  border-bottom: 0; }

.panel-heading + .list-group .list-group-item:first-child {
  border-top-width: 0; }

.panel > .table {
  margin-bottom: 0; }

.panel > .panel-body + .table {
  border-top: 1px solid #dddddd; }

.panel > .table-bordered {
  border: 0; }

.panel > .table-bordered > thead > tr > th:first-child,
.panel > .table-bordered > tbody > tr > th:first-child,
.panel > .table-bordered > tfoot > tr > th:first-child,
.panel > .table-bordered > thead > tr > td:first-child,
.panel > .table-bordered > tbody > tr > td:first-child,
.panel > .table-bordered > tfoot > tr > td:first-child {
  border-left: 0; }

.panel > .table-bordered > thead > tr > th:last-child,
.panel > .table-bordered > tbody > tr > th:last-child,
.panel > .table-bordered > tfoot > tr > th:last-child,
.panel > .table-bordered > thead > tr > td:last-child,
.panel > .table-bordered > tbody > tr > td:last-child,
.panel > .table-bordered > tfoot > tr > td:last-child {
  border-right: 0; }

.panel > .table-bordered > thead > tr:last-child > th,
.panel > .table-bordered > tbody > tr:last-child > th,
.panel > .table-bordered > tfoot > tr:last-child > th,
.panel > .table-bordered > thead > tr:last-child > td,
.panel > .table-bordered > tbody > tr:last-child > td,
.panel > .table-bordered > tfoot > tr:last-child > td {
  border-bottom: 0; }

.panel-heading {
  padding: 10px 15px;
  border-bottom: 1px solid transparent;
  border-top-right-radius: 3px;
  border-top-left-radius: 3px; }

.panel-title {
  margin-top: 0;
  margin-bottom: 0;
  font-size: 16px; }

.panel-title > a {
  color: inherit; }

.panel-footer {
  padding: 10px 15px;
  background-color: #f5f5f5;
  border-top: 1px solid #dddddd;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px; }

.panel-group .panel {
  margin-bottom: 0;
  overflow: hidden;
  border-radius: 4px; }

.panel-group .panel + .panel {
  margin-top: 5px; }

.panel-group .panel-heading {
  border-bottom: 0; }

.panel-group .panel-heading + .panel-collapse .panel-body {
  border-top: 1px solid #dddddd; }

.panel-group .panel-footer {
  border-top: 0; }

.panel-group .panel-footer + .panel-collapse .panel-body {
  border-bottom: 1px solid #dddddd; }

.panel-default {
  border-color: #dddddd; }

.panel-default > .panel-heading {
  color: #333333;
  background-color: #f5f5f5;
  border-color: #dddddd; }

.panel-default > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #dddddd; }

.panel-default > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #dddddd; }

.panel-primary {
  border-color: #428bca; }

.panel-primary > .panel-heading {
  color: #ffffff;
  background-color: #428bca;
  border-color: #428bca; }

.panel-primary > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #428bca; }

.panel-primary > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #428bca; }

.panel-success {
  border-color: #d6e9c6; }

.panel-success > .panel-heading {
  color: #468847;
  background-color: #dff0d8;
  border-color: #d6e9c6; }

.panel-success > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #d6e9c6; }

.panel-success > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #d6e9c6; }

.panel-warning {
  border-color: #faebcc; }

.panel-warning > .panel-heading {
  color: #c09853;
  background-color: #fcf8e3;
  border-color: #faebcc; }

.panel-warning > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #faebcc; }

.panel-warning > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #faebcc; }

.panel-danger {
  border-color: #ebccd1; }

.panel-danger > .panel-heading {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #ebccd1; }

.panel-danger > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #ebccd1; }

.panel-danger > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #ebccd1; }

.panel-info {
  border-color: #bce8f1; }

.panel-info > .panel-heading {
  color: #3a87ad;
  background-color: #d9edf7;
  border-color: #bce8f1; }

.panel-info > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #bce8f1; }

.panel-info > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #bce8f1; }

.well {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #e3e3e3;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05); }

.well blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15); }

.well-lg {
  padding: 24px;
  border-radius: 6px; }

.well-sm {
  padding: 9px;
  border-radius: 3px; }

.close {
  float: right;
  font-size: 21px;
  font-weight: bold;
  line-height: 1;
  color: #000000;
  text-shadow: 0 1px 0 #ffffff;
  opacity: 0.2;
  filter: alpha(opacity=20); }

.close:hover,
.close:focus {
  color: #000000;
  text-decoration: none;
  cursor: pointer;
  opacity: 0.5;
  filter: alpha(opacity=50); }

button.close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none; }

.modal-open {
  overflow: hidden; }

body.modal-open,
.modal-open .navbar-fixed-top,
.modal-open .navbar-fixed-bottom {
  margin-right: 15px; }

.modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  display: none;
  overflow: auto;
  overflow-y: scroll; }

.modal.fade .modal-dialog {
  -webkit-transform: translate(0, -25%);
  -ms-transform: translate(0, -25%);
  transform: translate(0, -25%);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -moz-transition: -moz-transform 0.3s ease-out;
  -o-transition: -o-transform 0.3s ease-out;
  transition: transform 0.3s ease-out; }

.modal.in .modal-dialog {
  -webkit-transform: translate(0, 0);
  -ms-transform: translate(0, 0);
  transform: translate(0, 0); }

.modal-dialog {
  z-index: 1050;
  width: auto;
  padding: 10px;
  margin-right: auto;
  margin-left: auto; }

.modal-content {
  position: relative;
  background-color: #ffffff;
  border: 1px solid #999999;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  outline: none;
  -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
  box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
  background-clip: padding-box; }

.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1030;
  background-color: #000000; }

.modal-backdrop.fade {
  opacity: 0;
  filter: alpha(opacity=0); }

.modal-backdrop.in {
  opacity: 0.5;
  filter: alpha(opacity=50); }

.modal-header {
  min-height: 16.428571429px;
  padding: 15px;
  border-bottom: 1px solid #e5e5e5; }

.modal-header .close {
  margin-top: -2px; }

.modal-title {
  margin: 0;
  line-height: 1.428571429; }

.modal-body {
  position: relative;
  padding: 20px; }

.modal-footer {
  padding: 19px 20px 20px;
  margin-top: 15px;
  text-align: right;
  border-top: 1px solid #e5e5e5; }

.modal-footer:before,
.modal-footer:after {
  display: table;
  content: " "; }

.modal-footer:after {
  clear: both; }

.modal-footer:before,
.modal-footer:after {
  display: table;
  content: " "; }

.modal-footer:after {
  clear: both; }

.modal-footer .btn + .btn {
  margin-bottom: 0;
  margin-left: 5px; }

.modal-footer .btn-group .btn + .btn {
  margin-left: -1px; }

.modal-footer .btn-block + .btn-block {
  margin-left: 0; }

@media screen and (min-width: 768px) {
  .modal-dialog {
    right: auto;
    left: 50%;
    width: 600px;
    padding-top: 30px;
    padding-bottom: 30px; }
  .modal-content {
    -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5); } }

.tooltip {
  position: absolute;
  z-index: 1030;
  display: block;
  font-size: 12px;
  line-height: 1.4;
  opacity: 0;
  filter: alpha(opacity=0);
  visibility: visible; }

.tooltip.in {
  opacity: 0.9;
  filter: alpha(opacity=90); }

.tooltip.top {
  padding: 5px 0;
  margin-top: -3px; }

.tooltip.right {
  padding: 0 5px;
  margin-left: 3px; }

.tooltip.bottom {
  padding: 5px 0;
  margin-top: 3px; }

.tooltip.left {
  padding: 0 5px;
  margin-left: -3px; }

.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: #ffffff;
  text-align: center;
  text-decoration: none;
  background-color: #000000;
  border-radius: 4px; }

.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid; }

.tooltip.top .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-top-color: #000000;
  border-width: 5px 5px 0; }

.tooltip.top-left .tooltip-arrow {
  bottom: 0;
  left: 5px;
  border-top-color: #000000;
  border-width: 5px 5px 0; }

.tooltip.top-right .tooltip-arrow {
  right: 5px;
  bottom: 0;
  border-top-color: #000000;
  border-width: 5px 5px 0; }

.tooltip.right .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-right-color: #000000;
  border-width: 5px 5px 5px 0; }

.tooltip.left .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-left-color: #000000;
  border-width: 5px 0 5px 5px; }

.tooltip.bottom .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-bottom-color: #000000;
  border-width: 0 5px 5px; }

.tooltip.bottom-left .tooltip-arrow {
  top: 0;
  left: 5px;
  border-bottom-color: #000000;
  border-width: 0 5px 5px; }

.tooltip.bottom-right .tooltip-arrow {
  top: 0;
  right: 5px;
  border-bottom-color: #000000;
  border-width: 0 5px 5px; }

.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1010;
  display: none;
  max-width: 276px;
  padding: 1px;
  text-align: left;
  white-space: normal;
  background-color: #ffffff;
  border: 1px solid #cccccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  background-clip: padding-box; }

.popover.top {
  margin-top: -10px; }

.popover.right {
  margin-left: 10px; }

.popover.bottom {
  margin-top: 10px; }

.popover.left {
  margin-left: -10px; }

.popover-title {
  padding: 8px 14px;
  margin: 0;
  font-size: 14px;
  font-weight: normal;
  line-height: 18px;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-radius: 5px 5px 0 0; }

.popover-content {
  padding: 9px 14px; }

.popover .arrow,
.popover .arrow:after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid; }

.popover .arrow {
  border-width: 11px; }

.popover .arrow:after {
  border-width: 10px;
  content: ""; }

.popover.top .arrow {
  bottom: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-color: #999999;
  border-top-color: rgba(0, 0, 0, 0.25);
  border-bottom-width: 0; }

.popover.top .arrow:after {
  bottom: 1px;
  margin-left: -10px;
  border-top-color: #ffffff;
  border-bottom-width: 0;
  content: " "; }

.popover.right .arrow {
  top: 50%;
  left: -11px;
  margin-top: -11px;
  border-right-color: #999999;
  border-right-color: rgba(0, 0, 0, 0.25);
  border-left-width: 0; }

.popover.right .arrow:after {
  bottom: -10px;
  left: 1px;
  border-right-color: #ffffff;
  border-left-width: 0;
  content: " "; }

.popover.bottom .arrow {
  top: -11px;
  left: 50%;
  margin-left: -11px;
  border-bottom-color: #999999;
  border-bottom-color: rgba(0, 0, 0, 0.25);
  border-top-width: 0; }

.popover.bottom .arrow:after {
  top: 1px;
  margin-left: -10px;
  border-bottom-color: #ffffff;
  border-top-width: 0;
  content: " "; }

.popover.left .arrow {
  top: 50%;
  right: -11px;
  margin-top: -11px;
  border-left-color: #999999;
  border-left-color: rgba(0, 0, 0, 0.25);
  border-right-width: 0; }

.popover.left .arrow:after {
  right: 1px;
  bottom: -10px;
  border-left-color: #ffffff;
  border-right-width: 0;
  content: " "; }

.carousel {
  position: relative; }

.carousel-inner {
  position: relative;
  width: 100%;
  overflow: hidden; }

.carousel-inner > .item {
  position: relative;
  display: none;
  -webkit-transition: 0.6s ease-in-out left;
  transition: 0.6s ease-in-out left; }

.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  display: block;
  height: auto;
  max-width: 100%;
  line-height: 1; }

.carousel-inner > .active,
.carousel-inner > .next,
.carousel-inner > .prev {
  display: block; }

.carousel-inner > .active {
  left: 0; }

.carousel-inner > .next,
.carousel-inner > .prev {
  position: absolute;
  top: 0;
  width: 100%; }

.carousel-inner > .next {
  left: 100%; }

.carousel-inner > .prev {
  left: -100%; }

.carousel-inner > .next.left,
.carousel-inner > .prev.right {
  left: 0; }

.carousel-inner > .active.left {
  left: -100%; }

.carousel-inner > .active.right {
  left: 100%; }

.carousel-control {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 15%;
  font-size: 20px;
  color: #ffffff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
  opacity: 0.5;
  filter: alpha(opacity=50); }

.carousel-control.left {
  background-image: -webkit-gradient(linear, 0 top, 100% top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0.0001)));
  background-image: -webkit-linear-gradient(left, color-stop(rgba(0, 0, 0, 0.5) 0), color-stop(rgba(0, 0, 0, 0.0001) 100%));
  background-image: -moz-linear-gradient(left, rgba(0, 0, 0, 0.5) 0, rgba(0, 0, 0, 0.0001) 100%);
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5) 0, rgba(0, 0, 0, 0.0001) 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1); }

.carousel-control.right {
  right: 0;
  left: auto;
  background-image: -webkit-gradient(linear, 0 top, 100% top, from(rgba(0, 0, 0, 0.0001)), to(rgba(0, 0, 0, 0.5)));
  background-image: -webkit-linear-gradient(left, color-stop(rgba(0, 0, 0, 0.0001) 0), color-stop(rgba(0, 0, 0, 0.5) 100%));
  background-image: -moz-linear-gradient(left, rgba(0, 0, 0, 0.0001) 0, rgba(0, 0, 0, 0.5) 100%);
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001) 0, rgba(0, 0, 0, 0.5) 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1); }

.carousel-control:hover,
.carousel-control:focus {
  color: #ffffff;
  text-decoration: none;
  opacity: 0.9;
  filter: alpha(opacity=90); }

.carousel-control .icon-prev,
.carousel-control .icon-next,
.carousel-control .glyphicon-chevron-left,
.carousel-control .glyphicon-chevron-right {
  position: absolute;
  top: 50%;
  z-index: 5;
  display: inline-block; }

.carousel-control .icon-prev,
.carousel-control .glyphicon-chevron-left {
  left: 50%; }

.carousel-control .icon-next,
.carousel-control .glyphicon-chevron-right {
  right: 50%; }

.carousel-control .icon-prev,
.carousel-control .icon-next {
  width: 20px;
  height: 20px;
  margin-top: -10px;
  margin-left: -10px;
  font-family: serif; }

.carousel-control .icon-prev:before {
  content: '\2039'; }

.carousel-control .icon-next:before {
  content: '\203A'; }

.carousel-indicators {
  position: absolute;
  bottom: 10px;
  left: 50%;
  z-index: 15;
  width: 60%;
  padding-left: 0;
  margin-left: -30%;
  text-align: center;
  list-style: none; }

.carousel-indicators li {
  display: inline-block;
  width: 10px;
  height: 10px;
  margin: 1px;
  text-indent: -999px;
  cursor: pointer;
  border: 1px solid #ffffff;
  border-radius: 10px; }

.carousel-indicators .active {
  width: 12px;
  height: 12px;
  margin: 0;
  background-color: #ffffff; }

.carousel-caption {
  position: absolute;
  right: 15%;
  bottom: 20px;
  left: 15%;
  z-index: 10;
  padding-top: 20px;
  padding-bottom: 20px;
  color: #ffffff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6); }

.carousel-caption .btn {
  text-shadow: none; }

@media screen and (min-width: 768px) {
  .carousel-control .glyphicons-chevron-left,
  .carousel-control .glyphicons-chevron-right .icon-prev,
  .carousel-control .icon-next {
    width: 30px;
    height: 30px;
    margin-top: -15px;
    margin-left: -15px;
    font-size: 30px; }
  .carousel-caption {
    right: 20%;
    left: 20%;
    padding-bottom: 30px; }
  .carousel-indicators {
    bottom: 20px; } }

.clearfix:before,
.clearfix:after {
  display: table;
  content: " "; }

.clearfix:after {
  clear: both; }

.center-block {
  display: block;
  margin-right: auto;
  margin-left: auto; }

.pull-right {
  float: right !important; }

.pull-left {
  float: left !important; }

.hide {
  display: none !important; }

.show {
  display: block !important; }

.invisible {
  visibility: hidden; }

.text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0; }

.affix {
  position: fixed; }

@-ms-viewport {
  width: device-width; }

@media screen and (max-width: 400px) {
  @-ms-viewport {
    width: 320px; } }

.hidden {
  display: none !important;
  visibility: hidden !important; }

.visible-xs {
  display: none !important; }

tr.visible-xs {
  display: none !important; }

th.visible-xs,
td.visible-xs {
  display: none !important; }

@media (max-width: 767px) {
  .visible-xs {
    display: block !important; }
  tr.visible-xs {
    display: table-row !important; }
  th.visible-xs,
  td.visible-xs {
    display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .visible-xs.visible-sm {
    display: block !important; }
  tr.visible-xs.visible-sm {
    display: table-row !important; }
  th.visible-xs.visible-sm,
  td.visible-xs.visible-sm {
    display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .visible-xs.visible-md {
    display: block !important; }
  tr.visible-xs.visible-md {
    display: table-row !important; }
  th.visible-xs.visible-md,
  td.visible-xs.visible-md {
    display: table-cell !important; } }

@media (min-width: 1200px) {
  .visible-xs.visible-lg {
    display: block !important; }
  tr.visible-xs.visible-lg {
    display: table-row !important; }
  th.visible-xs.visible-lg,
  td.visible-xs.visible-lg {
    display: table-cell !important; } }

.visible-sm {
  display: none !important; }

tr.visible-sm {
  display: none !important; }

th.visible-sm,
td.visible-sm {
  display: none !important; }

@media (max-width: 767px) {
  .visible-sm.visible-xs {
    display: block !important; }
  tr.visible-sm.visible-xs {
    display: table-row !important; }
  th.visible-sm.visible-xs,
  td.visible-sm.visible-xs {
    display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm {
    display: block !important; }
  tr.visible-sm {
    display: table-row !important; }
  th.visible-sm,
  td.visible-sm {
    display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .visible-sm.visible-md {
    display: block !important; }
  tr.visible-sm.visible-md {
    display: table-row !important; }
  th.visible-sm.visible-md,
  td.visible-sm.visible-md {
    display: table-cell !important; } }

@media (min-width: 1200px) {
  .visible-sm.visible-lg {
    display: block !important; }
  tr.visible-sm.visible-lg {
    display: table-row !important; }
  th.visible-sm.visible-lg,
  td.visible-sm.visible-lg {
    display: table-cell !important; } }

.visible-md {
  display: none !important; }

tr.visible-md {
  display: none !important; }

th.visible-md,
td.visible-md {
  display: none !important; }

@media (max-width: 767px) {
  .visible-md.visible-xs {
    display: block !important; }
  tr.visible-md.visible-xs {
    display: table-row !important; }
  th.visible-md.visible-xs,
  td.visible-md.visible-xs {
    display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .visible-md.visible-sm {
    display: block !important; }
  tr.visible-md.visible-sm {
    display: table-row !important; }
  th.visible-md.visible-sm,
  td.visible-md.visible-sm {
    display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md {
    display: block !important; }
  tr.visible-md {
    display: table-row !important; }
  th.visible-md,
  td.visible-md {
    display: table-cell !important; } }

@media (min-width: 1200px) {
  .visible-md.visible-lg {
    display: block !important; }
  tr.visible-md.visible-lg {
    display: table-row !important; }
  th.visible-md.visible-lg,
  td.visible-md.visible-lg {
    display: table-cell !important; } }

.visible-lg {
  display: none !important; }

tr.visible-lg {
  display: none !important; }

th.visible-lg,
td.visible-lg {
  display: none !important; }

@media (max-width: 767px) {
  .visible-lg.visible-xs {
    display: block !important; }
  tr.visible-lg.visible-xs {
    display: table-row !important; }
  th.visible-lg.visible-xs,
  td.visible-lg.visible-xs {
    display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .visible-lg.visible-sm {
    display: block !important; }
  tr.visible-lg.visible-sm {
    display: table-row !important; }
  th.visible-lg.visible-sm,
  td.visible-lg.visible-sm {
    display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .visible-lg.visible-md {
    display: block !important; }
  tr.visible-lg.visible-md {
    display: table-row !important; }
  th.visible-lg.visible-md,
  td.visible-lg.visible-md {
    display: table-cell !important; } }

@media (min-width: 1200px) {
  .visible-lg {
    display: block !important; }
  tr.visible-lg {
    display: table-row !important; }
  th.visible-lg,
  td.visible-lg {
    display: table-cell !important; } }

.hidden-xs {
  display: block !important; }

tr.hidden-xs {
  display: table-row !important; }

th.hidden-xs,
td.hidden-xs {
  display: table-cell !important; }

@media (max-width: 767px) {
  .hidden-xs {
    display: none !important; }
  tr.hidden-xs {
    display: none !important; }
  th.hidden-xs,
  td.hidden-xs {
    display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .hidden-xs.hidden-sm {
    display: none !important; }
  tr.hidden-xs.hidden-sm {
    display: none !important; }
  th.hidden-xs.hidden-sm,
  td.hidden-xs.hidden-sm {
    display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-xs.hidden-md {
    display: none !important; }
  tr.hidden-xs.hidden-md {
    display: none !important; }
  th.hidden-xs.hidden-md,
  td.hidden-xs.hidden-md {
    display: none !important; } }

@media (min-width: 1200px) {
  .hidden-xs.hidden-lg {
    display: none !important; }
  tr.hidden-xs.hidden-lg {
    display: none !important; }
  th.hidden-xs.hidden-lg,
  td.hidden-xs.hidden-lg {
    display: none !important; } }

.hidden-sm {
  display: block !important; }

tr.hidden-sm {
  display: table-row !important; }

th.hidden-sm,
td.hidden-sm {
  display: table-cell !important; }

@media (max-width: 767px) {
  .hidden-sm.hidden-xs {
    display: none !important; }
  tr.hidden-sm.hidden-xs {
    display: none !important; }
  th.hidden-sm.hidden-xs,
  td.hidden-sm.hidden-xs {
    display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .hidden-sm {
    display: none !important; }
  tr.hidden-sm {
    display: none !important; }
  th.hidden-sm,
  td.hidden-sm {
    display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-sm.hidden-md {
    display: none !important; }
  tr.hidden-sm.hidden-md {
    display: none !important; }
  th.hidden-sm.hidden-md,
  td.hidden-sm.hidden-md {
    display: none !important; } }

@media (min-width: 1200px) {
  .hidden-sm.hidden-lg {
    display: none !important; }
  tr.hidden-sm.hidden-lg {
    display: none !important; }
  th.hidden-sm.hidden-lg,
  td.hidden-sm.hidden-lg {
    display: none !important; } }

.hidden-md {
  display: block !important; }

tr.hidden-md {
  display: table-row !important; }

th.hidden-md,
td.hidden-md {
  display: table-cell !important; }

@media (max-width: 767px) {
  .hidden-md.hidden-xs {
    display: none !important; }
  tr.hidden-md.hidden-xs {
    display: none !important; }
  th.hidden-md.hidden-xs,
  td.hidden-md.hidden-xs {
    display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .hidden-md.hidden-sm {
    display: none !important; }
  tr.hidden-md.hidden-sm {
    display: none !important; }
  th.hidden-md.hidden-sm,
  td.hidden-md.hidden-sm {
    display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-md {
    display: none !important; }
  tr.hidden-md {
    display: none !important; }
  th.hidden-md,
  td.hidden-md {
    display: none !important; } }

@media (min-width: 1200px) {
  .hidden-md.hidden-lg {
    display: none !important; }
  tr.hidden-md.hidden-lg {
    display: none !important; }
  th.hidden-md.hidden-lg,
  td.hidden-md.hidden-lg {
    display: none !important; } }

.hidden-lg {
  display: block !important; }

tr.hidden-lg {
  display: table-row !important; }

th.hidden-lg,
td.hidden-lg {
  display: table-cell !important; }

@media (max-width: 767px) {
  .hidden-lg.hidden-xs {
    display: none !important; }
  tr.hidden-lg.hidden-xs {
    display: none !important; }
  th.hidden-lg.hidden-xs,
  td.hidden-lg.hidden-xs {
    display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
  .hidden-lg.hidden-sm {
    display: none !important; }
  tr.hidden-lg.hidden-sm {
    display: none !important; }
  th.hidden-lg.hidden-sm,
  td.hidden-lg.hidden-sm {
    display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-lg.hidden-md {
    display: none !important; }
  tr.hidden-lg.hidden-md {
    display: none !important; }
  th.hidden-lg.hidden-md,
  td.hidden-lg.hidden-md {
    display: none !important; } }

@media (min-width: 1200px) {
  .hidden-lg {
    display: none !important; }
  tr.hidden-lg {
    display: none !important; }
  th.hidden-lg,
  td.hidden-lg {
    display: none !important; } }

.visible-print {
  display: none !important; }

tr.visible-print {
  display: none !important; }

th.visible-print,
td.visible-print {
  display: none !important; }

@media print {
  .visible-print {
    display: block !important; }
  tr.visible-print {
    display: table-row !important; }
  th.visible-print,
  td.visible-print {
    display: table-cell !important; }
  .hidden-print {
    display: none !important; }
  tr.hidden-print {
    display: none !important; }
  th.hidden-print,
  td.hidden-print {
    display: none !important; } }
@-webkit-keyframes medium-editor-image-loading {
  0% {
    -webkit-transform: scale(0);
    transform: scale(0); }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1); } }

@keyframes medium-editor-image-loading {
  0% {
    -webkit-transform: scale(0);
    transform: scale(0); }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1); } }

@-webkit-keyframes medium-editor-pop-upwards {
  0% {
    opacity: 0;
    -webkit-transform: matrix(0.97, 0, 0, 1, 0, 12);
    transform: matrix(0.97, 0, 0, 1, 0, 12); }
  20% {
    opacity: .7;
    -webkit-transform: matrix(0.99, 0, 0, 1, 0, 2);
    transform: matrix(0.99, 0, 0, 1, 0, 2); }
  40% {
    opacity: 1;
    -webkit-transform: matrix(1, 0, 0, 1, 0, -1);
    transform: matrix(1, 0, 0, 1, 0, -1); }
  100% {
    -webkit-transform: matrix(1, 0, 0, 1, 0, 0);
    transform: matrix(1, 0, 0, 1, 0, 0); } }

@keyframes medium-editor-pop-upwards {
  0% {
    opacity: 0;
    -webkit-transform: matrix(0.97, 0, 0, 1, 0, 12);
    transform: matrix(0.97, 0, 0, 1, 0, 12); }
  20% {
    opacity: .7;
    -webkit-transform: matrix(0.99, 0, 0, 1, 0, 2);
    transform: matrix(0.99, 0, 0, 1, 0, 2); }
  40% {
    opacity: 1;
    -webkit-transform: matrix(1, 0, 0, 1, 0, -1);
    transform: matrix(1, 0, 0, 1, 0, -1); }
  100% {
    -webkit-transform: matrix(1, 0, 0, 1, 0, 0);
    transform: matrix(1, 0, 0, 1, 0, 0); } }

.medium-editor-anchor-preview {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 16px;
  left: 0;
  line-height: 1.4;
  max-width: 280px;
  position: absolute;
  text-align: center;
  top: 0;
  word-break: break-all;
  word-wrap: break-word;
  visibility: hidden;
  z-index: 2000; }

.medium-editor-anchor-preview a {
  color: #fff;
  display: inline-block;
  margin: 5px 5px 10px; }

.medium-editor-anchor-preview-active {
  visibility: visible; }

.medium-editor-dragover {
  background: #ddd; }

.medium-editor-image-loading {
  -webkit-animation: medium-editor-image-loading 1s infinite ease-in-out;
  animation: medium-editor-image-loading 1s infinite ease-in-out;
  background-color: #333;
  border-radius: 100%;
  display: inline-block;
  height: 40px;
  width: 40px; }

.medium-editor-placeholder {
  position: relative; }

.medium-editor-placeholder:after {
  content: attr(data-placeholder) !important;
  font-style: italic;
  left: 0;
  position: absolute;
  top: 0;
  white-space: pre;
  padding: inherit;
  margin: inherit; }

.medium-toolbar-arrow-under:after, .medium-toolbar-arrow-over:before {
  border-style: solid;
  content: '';
  display: block;
  height: 0;
  left: 50%;
  margin-left: -8px;
  position: absolute;
  width: 0; }

.medium-toolbar-arrow-under:after {
  border-width: 8px 8px 0 8px; }

.medium-toolbar-arrow-over:before {
  border-width: 0 8px 8px 8px;
  top: -8px; }

.medium-editor-toolbar {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 16px;
  left: 0;
  position: absolute;
  top: 0;
  visibility: hidden;
  z-index: 2000; }

.medium-editor-toolbar ul {
  margin: 0;
  padding: 0; }

.medium-editor-toolbar li {
  float: left;
  list-style: none;
  margin: 0;
  padding: 0; }

.medium-editor-toolbar li button {
  box-sizing: border-box;
  cursor: pointer;
  display: block;
  font-size: 14px;
  line-height: 1.33;
  margin: 0;
  padding: 15px;
  text-decoration: none; }

.medium-editor-toolbar li button:focus {
  outline: none; }

.medium-editor-toolbar li .medium-editor-action-underline {
  text-decoration: underline; }

.medium-editor-toolbar li .medium-editor-action-pre {
  font-family: Consolas, "Liberation Mono", Menlo, Courier, monospace;
  font-size: 12px;
  font-weight: 100;
  padding: 15px 0; }

.medium-editor-toolbar-active {
  visibility: visible; }

.medium-editor-sticky-toolbar {
  position: fixed;
  top: 1px; }

.medium-editor-relative-toolbar {
  position: relative; }

.medium-editor-toolbar-active.medium-editor-stalker-toolbar {
  -webkit-animation: medium-editor-pop-upwards 160ms forwards linear;
  animation: medium-editor-pop-upwards 160ms forwards linear; }

.medium-editor-action-bold {
  font-weight: bolder; }

.medium-editor-action-italic {
  font-style: italic; }

.medium-editor-toolbar-form {
  display: none; }

.medium-editor-toolbar-form input,
.medium-editor-toolbar-form a {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; }

.medium-editor-toolbar-form .medium-editor-toolbar-form-row {
  line-height: 14px;
  margin-left: 5px;
  padding-bottom: 5px; }

.medium-editor-toolbar-form .medium-editor-toolbar-input,
.medium-editor-toolbar-form label {
  border: none;
  box-sizing: border-box;
  font-size: 14px;
  margin: 0;
  padding: 6px;
  width: 316px;
  display: inline-block; }

.medium-editor-toolbar-form .medium-editor-toolbar-input:focus,
.medium-editor-toolbar-form label:focus {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  border: none;
  box-shadow: none;
  outline: 0; }

.medium-editor-toolbar-form a {
  display: inline-block;
  font-size: 24px;
  font-weight: bolder;
  margin: 0 10px;
  text-decoration: none; }

.medium-editor-toolbar-form-active {
  display: block; }

.medium-editor-toolbar-actions:after {
  clear: both;
  content: "";
  display: table; }

[data-medium-editor-element] {
  word-wrap: break-word;
  min-height: 30px; }

[data-medium-editor-element] img {
  max-width: 100%; }

[data-medium-editor-element] sub {
  vertical-align: sub; }

[data-medium-editor-element] sup {
  vertical-align: super; }

.medium-editor-hidden {
  display: none; }
.medium-toolbar-arrow-under:after {
  border-color: #242424 transparent transparent transparent;
  top: 50px; }

.medium-toolbar-arrow-over:before {
  border-color: transparent transparent #242424 transparent;
  top: -8px; }

.medium-editor-toolbar {
  background-color: #242424;
  background: -webkit-linear-gradient(top, #242424, rgba(36, 36, 36, 0.75));
  background: linear-gradient(to bottom, #242424, rgba(36, 36, 36, 0.75));
  border: 1px solid #000;
  border-radius: 5px;
  box-shadow: 0 0 3px #000; }

.medium-editor-toolbar li button {
  background-color: #242424;
  background: -webkit-linear-gradient(top, #242424, rgba(36, 36, 36, 0.89));
  background: linear-gradient(to bottom, #242424, rgba(36, 36, 36, 0.89));
  border: 0;
  border-right: 1px solid #000;
  border-left: 1px solid #333;
  border-left: 1px solid rgba(255, 255, 255, 0.1);
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.3);
  color: #fff;
  height: 50px;
  min-width: 50px;
  -webkit-transition: background-color .2s ease-in;
  transition: background-color .2s ease-in; }

.medium-editor-toolbar li button:hover {
  background-color: #000;
  color: yellow; }

.medium-editor-toolbar li .medium-editor-button-first {
  border-bottom-left-radius: 5px;
  border-top-left-radius: 5px; }

.medium-editor-toolbar li .medium-editor-button-last {
  border-bottom-right-radius: 5px;
  border-top-right-radius: 5px; }

.medium-editor-toolbar li .medium-editor-button-active {
  background-color: #000;
  background: -webkit-linear-gradient(top, #242424, rgba(0, 0, 0, 0.89));
  background: linear-gradient(to bottom, #242424, rgba(0, 0, 0, 0.89));
  color: #fff; }

.medium-editor-toolbar-form {
  background: #242424;
  border-radius: 5px;
  color: #999; }

.medium-editor-toolbar-form .medium-editor-toolbar-input {
  background: #242424;
  box-sizing: border-box;
  color: #ccc;
  height: 50px; }

.medium-editor-toolbar-form a {
  color: #fff; }

.medium-editor-toolbar-anchor-preview {
  background: #242424;
  border-radius: 5px;
  color: #fff; }

.medium-editor-placeholder:after {
  color: #b3b3b1; }
/*
Copyright 2015 Google Inc. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
.container {
  width: 100% !important; }

i {
  margin-right: 5px; }

body {
  /* #f9f9f9 -> #f1f1f1 */
  background: #f9f9f9;
  background: linear-gradient(90deg, #f9f9f9 11%, #f1f1f1 100%);
  line-height: 1.5;
  color: #333; }

table {
  table-layout: fixed;
  word-wrap: break-word; }

body > header {
  width: 100%;
  height: 55px;
  background: #34495e;
  position: fixed;
  top: 0;
  z-index: 9998;
  padding: 11px 21px 11px 15px; }

#logo {
  height: 50px;
  padding-top: 16px;
  position: fixed;
  top: 0; }

#logo img {
  width: 110px;
  height: 19px; }

#subheader {
  height: 60px;
  background: #fff;
  top: 55px;
  border-bottom: 1px solid #f1f1f1;
  position: fixed;
  z-index: 9998;
  width: 100%;
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.14), 0 4px 8px rgba(0, 0, 0, 0.28); }

#navigation {
  margin-left: 15px; }

#main {
  margin: 150px 30px 15px 30px; }

#sketch-name {
  color: #fff;
  font-size: 16px; }

.right-nav {
  padding: 10px;
  margin-right: 5px;
  margin-top: 2px; }

.card {
  margin-bottom: 20px;
  background: #fff;
  padding: 20px;
  box-shadow: 0 0 1px rgba(0, 0, 0, 0.15);
  border-radius: 5px; }

.card-header {
  background: #fff;
  padding: 10px 10px 10px 20px;
  margin: -20px -20px 0 -20px;
  min-height: 40px; }

.card-alert {
  background: red;
  color: #fff; }

.card h3 {
  margin-top: 0px; }

.card h4 {
  margin-top: 0px; }

.card-paragraph {
  letter-spacing: .01rem;
  font-weight: 400;
  font-style: normal;
  font-size: 16px;
  line-height: 1.5;
  max-width: 900px;
  margin-left: 3px;
  margin-top: 15px; }

.card-top {
  padding-top: 30px; }

.search-input {
  outline: none;
  border: none;
  box-shadow: none !important;
  font-size: 1.3em;
  border-radius: 5px;
  padding: 15px;
  background: #f9f9f9;
  width: 100%; }

.table > tbody > tr:first-child > td {
  border-top: none; }

#search-result-table {
  margin-bottom: 1px; }

#search-result-table td {
  vertical-align: top;
  padding: 10px; }

.event-message {
  background: #f9f9f9;
  padding: 10px 10px 10px 5px;
  cursor: pointer; }

.event-message-wrap {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.event-message-selected {
  background: #fafad2; }

.event-message-starred {
  background: #fff4b3; }

.event-message-details {
  background: #fafad2; }

.timerange-input {
  width: 210px;
  outline: none;
  border: 1px solid lightgrey !important;
  box-shadow: none !important;
  background: #fff; }

.timeline-picker-card {
  overflow: hidden;
  position: relative; }

.timeline-box {
  background: #fff;
  padding: 10px;
  border: 1px solid #d9d9d9;
  margin-right: 10px;
  cursor: pointer;
  margin-bottom: 5px; }

.color-box {
  width: 30px;
  height: 30px;
  margin-right: 10px;
  border-radius: 4px; }

.index-enabled {
  color: #333; }

.index-disabled {
  color: #d2d2d2;
  text-decoration: line-through; }

.timeline-title {
  margin-top: 5px; }

.timeline-checkbox {
  margin-top: 5px;
  margin-left: 10px; }

.btn:focus {
  outline: none; }

.btn-default:focus {
  background: #fff; }

.btn-primary {
  background: #0076d0; }

.select {
  background: #fff;
  height: 34px;
  border: 1px solid #d1d1d1;
  width: 150px;
  outline: none; }

.select-view {
  margin-left: 5px; }

#butterbar {
  display: none;
  width: 150px;
  background: #333;
  opacity: 0.6;
  color: #fff;
  padding: 10px;
  position: absolute;
  left: 0;
  right: 0;
  top: -11px;
  margin-left: auto;
  margin-right: auto;
  text-align: center;
  z-index: 9998; }

.modal {
  padding-top: 100px; }

#timelines, ul {
  list-style: none;
  padding: 0; }

.event-add {
  margin-top: 20px;
  margin-bottom: 20px; }

.event-detail-container {
  margin-top: 15px;
  margin-bottom: 35px;
  padding: 0;
  max-width: 100%; }

.event-insert-grow {
  padding: 1px 1px 1px 1px;
  position: relative;
  border-bottom: solid 0px;
  transition: border-bottom 0.5s;
  -webkit-transition: border-bottom 0.5s;
  overflow: hidden; }

.event-insert-grow:after {
  content: '';
  width: 100%;
  position: absolute;
  border-bottom: solid 0px;
  -webkit-transform: scaleX(0.0001);
  -ms-transform: scaleX(0.0001);
  transform: scaleX(0.0001);
  -webkit-transition: -webkit-transform 150ms ease-in-out;
  transition: transform 150ms ease-in-out; }

.event-insert-hover {
  border-bottom: solid 10px transparent; }

.event-insert-hover:after {
  -webkit-transform: scaleX(1);
  -ms-transform: scaleX(1);
  transform: scaleX(1); }

.btn-warning {
  background: #EB7F00; }

.icon-yellow {
  color: #ffe300;
  -webkit-text-stroke-width: 1px;
  -webkit-text-stroke-color: silver; }

.icon-grey {
  color: #d2d2d2; }

.btn-uppercase {
  text-transform: uppercase;
  font-size: 0.9em;
  letter-spacing: 1.0px; }

.comment-wrapper {
  margin-top: 20px;
  margin-bottom: 10px; }

.comment-bubble {
  position: relative;
  min-height: 100px;
  padding: 15px;
  background: #f5f5f5;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  margin-bottom: 10px; }

.comment-avatar {
  float: left; }

.comment-name {
  text-transform: capitalize;
  font-size: 1.1em;
  margin-bottom: 10px; }

.comment-body {
  overflow: hidden;
  margin-top: 2px; }

.comment-timestamp {
  font-weight: normal;
  font-size: 0.8em;
  color: #666;
  margin-top: 5px; }

.ts-name-label {
  color: #999; }

.btn-file {
  position: relative;
  overflow: hidden; }

.btn-file input[type=file] {
  position: absolute;
  top: 0;
  right: 0;
  min-width: 100%;
  min-height: 100%;
  font-size: 100px;
  text-align: right;
  filter: alpha(opacity=0);
  opacity: 0;
  outline: none;
  background: white;
  cursor: inherit;
  display: block; }

.form-control:focus {
  border-color: #d1d1d1;
  box-shadow: none !important; }

.btn-darkblue {
  background-color: #337ab7;
  border-color: #2e6da4; }

div.tooltips {
  position: relative;
  display: inline; }

div.tooltips span {
  position: absolute;
  width: 140px;
  color: #FFFFFF;
  background: #000000;
  height: 30px;
  line-height: 30px;
  text-align: center;
  visibility: hidden;
  border-radius: 6px; }

div.tooltips span:after {
  content: '';
  position: absolute;
  top: 50%;
  left: 100%;
  margin-top: -8px;
  width: 0;
  height: 0;
  border-left: 8px solid #000000;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent; }

div:hover.tooltips span {
  visibility: visible;
  opacity: 0.8;
  right: 100%;
  top: 50%;
  margin-top: -15px;
  margin-right: 15px;
  z-index: 999; }

.ts-progress-bar {
  height: 10px;
  margin-bottom: 0;
  margin-top: 5px; }

.ts-table-noborder tbody > tr > td {
  border-top: 0;
  padding: 5px; }

.ts-table-condensed {
  margin-bottom: 0; }

.ts-table-condensed tbody > tr > td {
  padding: 5px; }

.filter-card {
  padding-bottom: 10px; }

.filter-card, h5 {
  padding-bottom: 7px; }

rect.bordered {
  stroke: #d1d1d1;
  stroke-width: 1px; }

.nav-tabs {
  background: transparent;
  border: none;
  letter-spacing: .06rem; }

.nav-tabs > li > a, .nav-tabs > li > a:hover {
  background: transparent;
  color: #555;
  padding: 16px 5px 14px 5px;
  margin-top: 8px;
  border: none;
  font-weight: normal;
  margin-right: 20px;
  border-radius: 0; }

.nav-tabs > li > a:hover {
  background: transparent;
  border-bottom: 2px solid #d1d1d1; }

.nav-tabs > li.active > a, .nav-tabs > li.active > a:hover, .nav-tabs > li.active > a:focus {
  background: transparent;
  color: #333;
  border: none;
  border-bottom: 2px solid #0065bc;
  cursor: pointer; }

.nav-tabs-light > li > a, .nav-tabs-light > li > a:hover {
  color: #333;
  padding: 15px 15px 15px 15px;
  margin-top: -12px; }

.nav-tabs-light > li > a:hover {
  background: transparent;
  border-bottom: none; }

.nav-tabs-light > li.active .tab-filler {
  width: 100%;
  height: 3px;
  background-color: #fff;
  position: absolute;
  bottom: 0;
  left: 0;
  z-index: 10; }

.nav-tabs-light > li.active > a, .nav-tabs-light > li.active > a:hover, .nav-tabs-light > li.active > a:focus {
  color: #333;
  font-weight: bold;
  cursor: pointer;
  background: #fff;
  box-shadow: 0 0 1px rgba(0, 0, 0, 0.15);
  border: none; }

.timeline-bubble {
  margin-left: 100px;
  height: 100px;
  border-left: 2px solid #f5f5f5; }

.axis {
  font: 14px sans-serif; }

.axis path, .axis line {
  fill: none;
  stroke: #000;
  shape-rendering: crispEdges; }

.message-hidden {
  color: #666;
  font-style: italic; }

.btn {
  border-radius: 4px;
  letter-spacing: .06rem; }

.label {
  border-radius: 3px;
  letter-spacing: .06rem; }

.medium-editor-placeholder {
  position: relative; }

.medium-editor-placeholder:after {
  content: attr(data-placeholder) !important;
  font-style: normal;
  top: 0;
  left: 0;
  position: absolute;
  white-space: pre;
  padding: inherit;
  margin: inherit; }

.medium-editor-placeholder.editable:after {
  font-weight: 400;
  font-style: normal;
  font-size: 18px;
  line-height: 1.68;
  letter-spacing: -.003rem; }

p {
  margin-bottom: 30px;
  font-weight: 400;
  font-style: normal;
  font-size: 16px;
  line-height: 1.58;
  letter-spacing: .01rem; }

.editable p {
  font-weight: 400;
  font-style: normal;
  font-size: 18px;
  line-height: 1.68;
  letter-spacing: -.003rem; }

h3 {
  margin-bottom: 30px;
  font-family: "Roboto", Helvetica, Arial, sans-serif; }

h1.editable-title {
  padding: 0;
  margin: 0;
  font-family: "Roboto", Helvetica, Arial, sans-serif; }

h2.editable {
  padding: 0;
  margin: 0;
  font-family: "Roboto", Helvetica, Arial, sans-serif; }

h3.editable {
  padding: 0;
  margin: 0;
  font-family: "Roboto", Helvetica, Arial, sans-serif; }

.editable:focus {
  outline: 0 solid transparent; }

.editable-title:focus {
  outline: 0 solid transparent; }

#json-editor {
  position: relative;
  height: 300px;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0; }

ul.content-list {
  list-style: none; }

ul.content-list > li {
  padding-top: 15px;
  padding-bottom: 15px;
  border-bottom: 1px solid #eee;
  display: block;
  margin: 0; }

ul.content-list > li:hover {
  background: #fcfcfc; }

ul.content-list > li:last-child {
  border-bottom: none; }

@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto"), local("Roboto-Regular"), url("/static/fonts/Roboto/Roboto-Regular.ttf") format("truetype"); }

ts-graphs-cytoscape {
  position: absolute;
  top: 0px;
  bottom: 0px;
  left: 0px;
  right: 0px;
  width: 100%;
  height: 100%; }
  ts-graphs-cytoscape div {
    position: absolute;
    top: 0px;
    bottom: 0px;
    left: 0px;
    right: 0px;
    width: 100%;
    height: 100%; }

ts-graphs-cypher-query button[type="submit"] i {
  color: #999; }

ts-graphs-cypher-query .ts-graphs-cypher-query__predefined-queries {
  height: 57px;
  min-width: 300px;
  background-color: #f9f9f9;
  margin-right: 10px;
  border: 0px;
  -webkit-border-radius: 0px; }

ts-graphs-graph-view {
  position: absolute;
  top: 0px;
  bottom: 0px;
  left: 0px;
  right: 0px;
  width: 100%;
  height: 100%; }
  ts-graphs-graph-view .ts-graphs-graph-view__dropdown {
    background-color: white;
    display: inline-block;
    vertical-align: top;
    position: relative;
    z-index: 10; }
    ts-graphs-graph-view .ts-graphs-graph-view__dropdown label {
      display: inline-block;
      padding-left: 15px;
      padding-right: 15px;
      padding-top: 10px;
      margin: 0px; }
  ts-graphs-graph-view .ts-graphs-graph-view__dropdown-trigger {
    display: none; }
  ts-graphs-graph-view .ts-graphs-graph-view__dropdown-content {
    position: absolute;
    left: 0px;
    top: 30px;
    z-index: 10;
    background-color: white;
    box-shadow: 0 0 1px rgba(0, 0, 0, 0.3);
    padding: 5px; }
  ts-graphs-graph-view .pull-left .ts-graphs-graph-view__dropdown-content {
    left: 0px;
    right: auto; }
  ts-graphs-graph-view .pull-right .ts-graphs-graph-view__dropdown-content {
    right: 0px;
    left: auto; }
  ts-graphs-graph-view .ts-graphs-graph-view__dropdown-trigger ~ .ts-graphs-graph-view__dropdown-content {
    display: none; }
  ts-graphs-graph-view .ts-graphs-graph-view__dropdown-trigger:checked ~ .ts-graphs-graph-view__dropdown-content {
    display: block; }
  ts-graphs-graph-view .ts-graphs-graph-view__sidebar {
    bottom: 0px;
    padding: 10px;
    overflow-x: hidden;
    overflow-y: auto;
    background-color: white;
    border-right: solid 1px #eeeeee;
    opacity: 0.9;
    box-shadow: none; }
  ts-graphs-graph-view .ts-graphs-graph-view__sidebar-hint {
    padding: 20px;
    text-align: center; }
  ts-graphs-graph-view .ts-graphs-graph-view__sidebar-width {
    display: none; }
  ts-graphs-graph-view .ts-graphs-graph-view__sidebar-width-label {
    display: none;
    padding-left: 15px;
    padding-right: 15px;
    padding-top: 0px;
    padding-bottom: 0px;
    margin: 0px; }
  ts-graphs-graph-view .ts-graphs-graph-view__sidebar-width-label {
    color: #b4b4b4; }
    ts-graphs-graph-view .ts-graphs-graph-view__sidebar-width-label i {
      color: #b4b4b4; }
    ts-graphs-graph-view .ts-graphs-graph-view__sidebar-width-label i::before {
      display: inline-block;
      box-shadow: 0px 0px 0px 3px #b4b4b4 inset; }
  ts-graphs-graph-view .ts-graphs-graph-view__dropdown-trigger:checked ~ .ts-graphs-graph-view__sidebar-width-label {
    display: inline-block;
    z-index: 10;
    position: relative; }
  ts-graphs-graph-view .ts-graphs-graph-view__sidebar-width:checked + label {
    background-color: #f0f0f0;
    color: black; }
  ts-graphs-graph-view #ts-graphs-graph-view__sidebar-width15:checked ~ .ts-graphs-graph-view__sidebar {
    width: 15vw; }
  ts-graphs-graph-view #ts-graphs-graph-view__sidebar-width30:checked ~ .ts-graphs-graph-view__sidebar {
    width: 30vw; }
  ts-graphs-graph-view #ts-graphs-graph-view__sidebar-width60:checked ~ .ts-graphs-graph-view__sidebar {
    width: 60vw; }
  ts-graphs-graph-view h3 {
    text-align: center;
    margin-top: 3em; }

ts-graphs-sidebar header {
  display: block;
  margin: 0px;
  padding: 10px 10px 10px 2px; }

ts-graphs-sidebar h4 {
  font-family: FontAwesome, sans-serif;
  text-align: left;
  display: inline-block;
  margin: 0px;
  margin-right: 0.5em; }

ts-graphs-sidebar mark {
  color: gray;
  background-color: transparent;
  display: inline-block; }

ts-graphs-main {
  height: calc(100vh - 150px);
  width: 100%;
  display: flex;
  flex-direction: column; }
  ts-graphs-main div.card {
    flex-grow: 1;
    flex-shrink: 1;
    position: relative; }

.fa-times-thin:before {
  content: '\D7';
  vertical-align: text-top; }
